@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,26 +17,22 @@
 """
 Package "timeflow"
 """
-API_VERSION = "1.9.3"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_9_3 import response_validator
+from delphixpy.v1_10_0.web.timeflow import bookmark
+from delphixpy.v1_10_0.web.timeflow import oracle
+from urllib.parse import urlencode
+from delphixpy.v1_10_0 import response_validator
 
 def get(engine, ref):
     """
     Retrieve the specified Timeflow object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_3.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_9_3.web.objects.Timeflow.Timeflow` object
+        :py:class:`delphixpy.v1_10_0.web.objects.Timeflow.Timeflow` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_9_3.web.vo.Timeflow`
+    :rtype: :py:class:`v1_10_0.web.vo.Timeflow`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/timeflow/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -49,12 +44,11 @@ def get_all(engine, database=None):
     List Timeflow objects on the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_3.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_0.delphix_engine.DelphixEngine`
     :param database: List only TimeFlows within this database.
-    :type database: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_9_3.web.vo.Timeflow`
+    :type database: ``str``
+    :rtype: ``list`` of :py:class:`v1_10_0.web.vo.Timeflow`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/timeflow"
     query_params = {"database": database}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -71,14 +65,13 @@ def update(engine, ref, timeflow=None):
     Update the specified Timeflow object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_3.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_9_3.web.objects.Timeflow.Timeflow` object
+        :py:class:`delphixpy.v1_10_0.web.objects.Timeflow.Timeflow` object
     :type ref: ``str``
     :param timeflow: Payload object.
-    :type timeflow: :py:class:`v1_9_3.web.vo.Timeflow`
+    :type timeflow: :py:class:`v1_10_0.web.vo.Timeflow`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/timeflow/%s" % ref
     response = engine.post(url, timeflow.to_dict(dirty=True) if timeflow else None)
     result = response_validator.validate(response, engine)
@@ -90,16 +83,15 @@ def timeflow_ranges(engine, ref, timeflow_range_parameters=None):
     Fetches TimeFlow ranges in between the specified start and end locations.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_3.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_9_3.web.objects.Timeflow.Timeflow` object
+        :py:class:`delphixpy.v1_10_0.web.objects.Timeflow.Timeflow` object
     :type ref: ``str``
     :param timeflow_range_parameters: Payload object.
     :type timeflow_range_parameters:
-        :py:class:`v1_9_3.web.vo.TimeflowRangeParameters`
-    :rtype: ``list`` of :py:class:`v1_9_3.web.vo.TimeflowRange`
+        :py:class:`v1_10_0.web.vo.TimeflowRangeParameters`
+    :rtype: ``list`` of :py:class:`v1_10_0.web.vo.TimeflowRange`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/timeflow/%s/timeflowRanges" % ref
     response = engine.post(url, timeflow_range_parameters.to_dict(dirty=True) if timeflow_range_parameters else None)
     result = response_validator.validate(response, engine)
@@ -111,15 +103,14 @@ def repair(engine, ref, timeflow_repair_parameters=None):
     Manually fetch log files to repair a portion of a TimeFlow.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_3.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_9_3.web.objects.Timeflow.Timeflow` object
+        :py:class:`delphixpy.v1_10_0.web.objects.Timeflow.Timeflow` object
     :type ref: ``str``
     :param timeflow_repair_parameters: Payload object.
     :type timeflow_repair_parameters:
-        :py:class:`v1_9_3.web.vo.TimeflowRepairParameters`
+        :py:class:`v1_10_0.web.vo.TimeflowRepairParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/timeflow/%s/repair" % ref
     response = engine.post(url, timeflow_repair_parameters.to_dict(dirty=True) if timeflow_repair_parameters else None)
     result = response_validator.validate(response, engine)
@@ -131,12 +122,11 @@ def delete(engine, ref):
     Deletes a TimeFlow.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_3.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_9_3.web.objects.Timeflow.Timeflow` object
+        :py:class:`delphixpy.v1_10_0.web.objects.Timeflow.Timeflow` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/timeflow/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
