@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,44 +17,37 @@
 """
 Package "analytics"
 """
-API_VERSION = "1.11.10"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_10 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_10_1 import response_validator
 
 def create(engine, statistic_slice=None):
     """
     Create a new StatisticSlice object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param statistic_slice: Payload object.
-    :type statistic_slice: :py:class:`v1_11_10.web.vo.StatisticSlice`
-    :rtype: ``TEXT_TYPE``
+    :type statistic_slice: :py:class:`v1_10_1.web.vo.StatisticSlice`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/analytics"
     response = engine.post(url, statistic_slice.to_dict(dirty=True) if statistic_slice else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified StatisticSlice object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_10.web.objects.StatisticSlice.StatisticSlice
-        ` object
+        :py:class:`delphixpy.v1_10_1.web.objects.StatisticSlice.StatisticSlice`
+        object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_10.web.vo.StatisticSlice`
+    :rtype: :py:class:`v1_10_1.web.vo.StatisticSlice`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/analytics/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -67,10 +59,9 @@ def get_all(engine):
     Returns a list of statistics in the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of :py:class:`v1_11_10.web.vo.StatisticSlice`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_10_1.web.vo.StatisticSlice`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/analytics"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -82,35 +73,34 @@ def delete(engine, ref):
     Delete the specified StatisticSlice object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_10.web.objects.StatisticSlice.StatisticSlice
-        ` object
+        :py:class:`delphixpy.v1_10_1.web.objects.StatisticSlice.StatisticSlice`
+        object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/analytics/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
     return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
 
-def get_data(engine, ref, start_time=None, end_time=None, resolution=None, count=None):
+def get_data(engine, ref, start_time=None, end_time=None, resolution=None):
     """
     Returns data for the specified time range. If no time range is specified,
     the most recent data will be returned. Time ranges are limited to 1 hour of
     1-second data, 1 day of 1-minute data, and 1 month of 1-hour data.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_10.web.objects.StatisticSlice.StatisticSlice
-        ` object
+        :py:class:`delphixpy.v1_10_1.web.objects.StatisticSlice.StatisticSlice`
+        object
     :type ref: ``str``
     :param start_time: None
-    :type start_time: ``TEXT_TYPE``
+    :type start_time: ``str``
     :param end_time: None
-    :type end_time: ``TEXT_TYPE``
+    :type end_time: ``str``
     :param resolution: The time interval each datapoint should represent,
         measured in seconds. If datapoints of the desired resolution are not
         available, datapoints of the next smallest available resolution will be
@@ -118,15 +108,10 @@ def get_data(engine, ref, start_time=None, end_time=None, resolution=None, count
         available resolution, then the lowest available resolution will be
         used.
     :type resolution: ``int``
-    :param count: The number of data points to return. Mds data points will be
-        combined in order to to meet this requirement. When count is specified
-        at least two of the other getData parameters must be specified.
-    :type count: ``int``
-    :rtype: :py:class:`v1_11_10.web.vo.DatapointSet`
+    :rtype: :py:class:`v1_10_1.web.vo.DatapointSet`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/analytics/%s/getData" % ref
-    query_params = {"startTime": start_time, "endTime": end_time, "resolution": resolution, "count": count}
+    query_params = {"startTime": start_time, "endTime": end_time, "resolution": resolution}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
     if query_dct:
         url_params = urlencode(query_dct)
@@ -141,16 +126,14 @@ def remember_range(engine, ref, time_range_parameters):
     Prevents data from being deleted automatically.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_10.web.objects.StatisticSlice.StatisticSlice
-        ` object
+        :py:class:`delphixpy.v1_10_1.web.objects.StatisticSlice.StatisticSlice`
+        object
     :type ref: ``str``
     :param time_range_parameters: Payload object.
-    :type time_range_parameters:
-        :py:class:`v1_11_10.web.vo.TimeRangeParameters`
+    :type time_range_parameters: :py:class:`v1_10_1.web.vo.TimeRangeParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/analytics/%s/rememberRange" % ref
     response = engine.post(url, time_range_parameters.to_dict(dirty=True) if time_range_parameters else None)
     result = response_validator.validate(response, engine)
@@ -162,16 +145,14 @@ def stop_remembering_range(engine, ref, time_range_parameters):
     Allows saved data to be deleted automatically if it is getting old.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_10.web.objects.StatisticSlice.StatisticSlice
-        ` object
+        :py:class:`delphixpy.v1_10_1.web.objects.StatisticSlice.StatisticSlice`
+        object
     :type ref: ``str``
     :param time_range_parameters: Payload object.
-    :type time_range_parameters:
-        :py:class:`v1_11_10.web.vo.TimeRangeParameters`
+    :type time_range_parameters: :py:class:`v1_10_1.web.vo.TimeRangeParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/analytics/%s/stopRememberingRange" % ref
     response = engine.post(url, time_range_parameters.to_dict(dirty=True) if time_range_parameters else None)
     result = response_validator.validate(response, engine)
@@ -183,13 +164,12 @@ def pause(engine, ref):
     Pauses the collection of data for this slice.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_10.web.objects.StatisticSlice.StatisticSlice
-        ` object
+        :py:class:`delphixpy.v1_10_1.web.objects.StatisticSlice.StatisticSlice`
+        object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/analytics/%s/pause" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -201,13 +181,12 @@ def resume(engine, ref):
     Resumes the collection of data for this slice.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_10.web.objects.StatisticSlice.StatisticSlice
-        ` object
+        :py:class:`delphixpy.v1_10_1.web.objects.StatisticSlice.StatisticSlice`
+        object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/analytics/%s/resume" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
