@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,44 +17,37 @@
 """
 Package "selfservice.bookmark"
 """
-API_VERSION = "1.11.13"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_13 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_10_1 import response_validator
 
 def create(engine, js_bookmark_create_parameters):
     """
     Create a new JSBookmark object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_13.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param js_bookmark_create_parameters: Payload object.
     :type js_bookmark_create_parameters:
-        :py:class:`v1_11_13.web.vo.JSBookmarkCreateParameters`
-    :rtype: ``TEXT_TYPE``
+        :py:class:`v1_10_1.web.vo.JSBookmarkCreateParameters`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/bookmark"
     response = engine.post(url, js_bookmark_create_parameters.to_dict(dirty=True) if js_bookmark_create_parameters else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified JSBookmark object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_13.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_13.web.objects.JSBookmark.JSBookmark` object
+        :py:class:`delphixpy.v1_10_1.web.objects.JSBookmark.JSBookmark` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_13.web.vo.JSBookmark`
+    :rtype: :py:class:`v1_10_1.web.vo.JSBookmark`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/bookmark/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -67,17 +59,16 @@ def get_all(engine, container=None, template=None):
     Lists the Self-Service bookmarks in the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_13.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param container: List all usable bookmarks accessible to the specified
         data container. This option is mutually exclusive with all other
         options.
-    :type container: ``TEXT_TYPE``
+    :type container: ``str``
     :param template: List all usable bookmarks created in the specified data
         template. This option is mutually exclusive with all other options.
-    :type template: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_11_13.web.vo.JSBookmark`
+    :type template: ``str``
+    :rtype: ``list`` of :py:class:`v1_10_1.web.vo.JSBookmark`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/bookmark"
     query_params = {"container": container, "template": template}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -94,14 +85,13 @@ def update(engine, ref, js_bookmark=None):
     Update the specified JSBookmark object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_13.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_13.web.objects.JSBookmark.JSBookmark` object
+        :py:class:`delphixpy.v1_10_1.web.objects.JSBookmark.JSBookmark` object
     :type ref: ``str``
     :param js_bookmark: Payload object.
-    :type js_bookmark: :py:class:`v1_11_13.web.vo.JSBookmark`
+    :type js_bookmark: :py:class:`v1_10_1.web.vo.JSBookmark`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/bookmark/%s" % ref
     response = engine.post(url, js_bookmark.to_dict(dirty=True) if js_bookmark else None)
     result = response_validator.validate(response, engine)
@@ -113,12 +103,11 @@ def delete(engine, ref):
     Delete the specified JSBookmark object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_13.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_13.web.objects.JSBookmark.JSBookmark` object
+        :py:class:`delphixpy.v1_10_1.web.objects.JSBookmark.JSBookmark` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/bookmark/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -130,12 +119,11 @@ def share(engine, ref):
     Shares the bookmark.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_13.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_13.web.objects.JSBookmark.JSBookmark` object
+        :py:class:`delphixpy.v1_10_1.web.objects.JSBookmark.JSBookmark` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/bookmark/%s/share" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -147,12 +135,11 @@ def unshare(engine, ref):
     Unshares the bookmark.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_13.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_13.web.objects.JSBookmark.JSBookmark` object
+        :py:class:`delphixpy.v1_10_1.web.objects.JSBookmark.JSBookmark` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/bookmark/%s/unshare" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -164,13 +151,12 @@ def get_create_bookmark_operation(engine, ref):
     Returns the CREATE_BOOKMARK operation associated with the bookmark.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_13.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_13.web.objects.JSBookmark.JSBookmark` object
+        :py:class:`delphixpy.v1_10_1.web.objects.JSBookmark.JSBookmark` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_13.web.vo.JSOperation`
+    :rtype: :py:class:`v1_10_1.web.vo.JSOperation`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/bookmark/%s/getCreateBookmarkOperation" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -182,13 +168,12 @@ def list_data_children(engine, ref):
     Lists the data children of this bookmark.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_13.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_13.web.objects.JSBookmark.JSBookmark` object
+        :py:class:`delphixpy.v1_10_1.web.objects.JSBookmark.JSBookmark` object
     :type ref: ``str``
-    :rtype: ``list`` of :py:class:`v1_11_13.web.vo.JSDataChild`
+    :rtype: ``list`` of :py:class:`v1_10_1.web.vo.JSDataChild`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/bookmark/%s/listDataChildren" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -202,15 +187,14 @@ def list_by_top_checkouts(engine, template=None, max_result_size=None):
     maxResultSize bookmarks.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_13.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param template: The given data template.
-    :type template: ``TEXT_TYPE``
+    :type template: ``str``
     :param max_result_size: The maximum number of results to return. A value of
         0 means all are returned.
     :type max_result_size: ``int``
-    :rtype: ``list`` of :py:class:`v1_11_13.web.vo.JSBookmark`
+    :rtype: ``list`` of :py:class:`v1_10_1.web.vo.JSBookmark`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/bookmark/listByTopCheckouts"
     query_params = {"template": template, "maxResultSize": max_result_size}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
