@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,40 +17,36 @@
 """
 Package "service.snmp.manager"
 """
-API_VERSION = "1.10.2"
-
-from delphixpy.v1_10_2 import response_validator
+from delphixpy.v1_10_1 import response_validator
 
 def create(engine, snmp_manager=None):
     """
     Create a new SNMPManager object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_10_2.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param snmp_manager: Payload object.
-    :type snmp_manager: :py:class:`v1_10_2.web.vo.SNMPManager`
-    :rtype: ``TEXT_TYPE``
+    :type snmp_manager: :py:class:`v1_10_1.web.vo.SNMPManager`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/snmp/manager"
     response = engine.post(url, snmp_manager.to_dict(dirty=True) if snmp_manager else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified SNMPManager object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_10_2.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_10_2.web.objects.SNMPManager.SNMPManager`
+        :py:class:`delphixpy.v1_10_1.web.objects.SNMPManager.SNMPManager`
         object
     :type ref: ``str``
-    :rtype: :py:class:`v1_10_2.web.vo.SNMPManager`
+    :rtype: :py:class:`v1_10_1.web.vo.SNMPManager`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/snmp/manager/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -63,10 +58,9 @@ def get_all(engine):
     Lists SNMP managers in the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_10_2.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of :py:class:`v1_10_2.web.vo.SNMPManager`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_10_1.web.vo.SNMPManager`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/snmp/manager"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -78,15 +72,14 @@ def update(engine, ref, snmp_manager=None):
     Update the specified SNMPManager object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_10_2.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_10_2.web.objects.SNMPManager.SNMPManager`
+        :py:class:`delphixpy.v1_10_1.web.objects.SNMPManager.SNMPManager`
         object
     :type ref: ``str``
     :param snmp_manager: Payload object.
-    :type snmp_manager: :py:class:`v1_10_2.web.vo.SNMPManager`
+    :type snmp_manager: :py:class:`v1_10_1.web.vo.SNMPManager`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/snmp/manager/%s" % ref
     response = engine.post(url, snmp_manager.to_dict(dirty=True) if snmp_manager else None)
     result = response_validator.validate(response, engine)
@@ -98,13 +91,12 @@ def delete(engine, ref):
     Delete the specified SNMPManager object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_10_2.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_10_2.web.objects.SNMPManager.SNMPManager`
+        :py:class:`delphixpy.v1_10_1.web.objects.SNMPManager.SNMPManager`
         object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/snmp/manager/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -117,13 +109,12 @@ def test(engine, ref):
     applies when useInform is true).
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_10_2.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_10_2.web.objects.SNMPManager.SNMPManager`
+        :py:class:`delphixpy.v1_10_1.web.objects.SNMPManager.SNMPManager`
         object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/snmp/manager/%s/test" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
