@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,40 +17,36 @@
 """
 Package "service.tls.csr"
 """
-API_VERSION = "1.11.11"
-
-from delphixpy.v1_11_11 import response_validator
+from delphixpy.v1_10_1 import response_validator
 
 def create(engine, certificate_signing_request_create_parameters):
     """
     Create a new CertificateSigningRequest object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param certificate_signing_request_create_parameters: Payload object.
     :type certificate_signing_request_create_parameters:
-        :py:class:`v1_11_11.web.vo.CertificateSigningRequestCreateParameters`
-    :rtype: ``TEXT_TYPE``
+        :py:class:`v1_10_1.web.vo.CertificateSigningRequestCreateParameters`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/tls/csr"
     response = engine.post(url, certificate_signing_request_create_parameters.to_dict(dirty=True) if certificate_signing_request_create_parameters else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified CertificateSigningRequest object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_11.web.objects.Certif
-        icateSigningRequest.CertificateSigningRequest` object
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_10_1.web.objects.Certifi
+        cateSigningRequest.CertificateSigningRequest` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_11.web.vo.CertificateSigningRequest`
+    :rtype: :py:class:`v1_10_1.web.vo.CertificateSigningRequest`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/tls/csr/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -63,10 +58,9 @@ def get_all(engine):
     List CertificateSigningRequest objects on the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of :py:class:`v1_11_11.web.vo.CertificateSigningRequest`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_10_1.web.vo.CertificateSigningRequest`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/tls/csr"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -78,12 +72,11 @@ def delete(engine, ref):
     Delete the specified CertificateSigningRequest object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_11.web.objects.Certif
-        icateSigningRequest.CertificateSigningRequest` object
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_10_1.web.objects.Certifi
+        cateSigningRequest.CertificateSigningRequest` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/tls/csr/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -95,16 +88,15 @@ def validate_dname(engine, x500_distinguished_name):
     Validate distinguished name.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_1.delphix_engine.DelphixEngine`
     :param x500_distinguished_name: Payload object.
     :type x500_distinguished_name:
-        :py:class:`v1_11_11.web.vo.X500DistinguishedName`
-    :rtype: ``TEXT_TYPE``
+        :py:class:`v1_10_1.web.vo.X500DistinguishedName`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/tls/csr/validateDname"
     response = engine.post(url, x500_distinguished_name.to_dict(dirty=True) if x500_distinguished_name else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
