@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,27 +17,21 @@
 """
 Package "selfservice.usage.template"
 """
-API_VERSION = "1.11.14"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_14 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_10_2 import response_validator
 
 def list_template_usage_data(engine, template=None):
     """
     Lists the usage breakdown for data templates.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_14.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_2.delphix_engine.DelphixEngine`
     :param template: If passed in, this query parameter restricts the API to
         only return the usage information for the given data template. By
         default, the usage information for all data templates is returned.
-    :type template: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_11_14.web.vo.JSTemplateUsageData`
+    :type template: ``str``
+    :rtype: ``list`` of :py:class:`v1_10_2.web.vo.JSTemplateUsageData`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/usage/template/listTemplateUsageData"
     query_params = {"template": template}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
