@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +17,7 @@
 """
 Package "selfservice.usage.user"
 """
-API_VERSION = "1.10.2"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy.v1_10_2 import response_validator
 
 def list_user_usage_data(engine, user=None):
@@ -35,10 +29,9 @@ def list_user_usage_data(engine, user=None):
     :param user: If passed in, this query parameter restricts the API to only
         return the usage information for the given user. By default, the usage
         information for all users is returned.
-    :type user: ``TEXT_TYPE``
+    :type user: ``str``
     :rtype: ``list`` of :py:class:`v1_10_2.web.vo.JSUserUsageData`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/usage/user/listUserUsageData"
     query_params = {"user": user}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
