@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,26 +17,20 @@
 """
 Package "service.tls.cipherSuite"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_16 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_10_2 import response_validator
 
 def get_all(engine, https_default=None):
     """
     Lists all of the supported cipher suites.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_16.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_2.delphix_engine.DelphixEngine`
     :param https_default: If true, returns just the default list of ciphers for
         HTTPS.
     :type https_default: ``bool``
-    :rtype: ``list`` of :py:class:`v1_11_16.web.vo.CipherSuite`
+    :rtype: ``list`` of :py:class:`v1_10_2.web.vo.CipherSuite`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/tls/cipherSuite"
     query_params = {"httpsDefault": https_default}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
