@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,40 +17,36 @@
 """
 Package "network.test.latency"
 """
-API_VERSION = "1.11.1"
-
-from delphixpy.v1_11_1 import response_validator
+from delphixpy.v1_10_3 import response_validator
 
 def create(engine, network_latency_test_parameters):
     """
     Create a new NetworkLatencyTest object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_1.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_3.delphix_engine.DelphixEngine`
     :param network_latency_test_parameters: Payload object.
     :type network_latency_test_parameters:
-        :py:class:`v1_11_1.web.vo.NetworkLatencyTestParameters`
-    :rtype: ``TEXT_TYPE``
+        :py:class:`v1_10_3.web.vo.NetworkLatencyTestParameters`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/network/test/latency"
     response = engine.post(url, network_latency_test_parameters.to_dict(dirty=True) if network_latency_test_parameters else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified NetworkLatencyTest object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_1.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_1.web.objects.Network
+    :type engine: :py:class:`delphixpy.v1_10_3.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_10_3.web.objects.Network
         LatencyTest.NetworkLatencyTest` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_1.web.vo.NetworkLatencyTest`
+    :rtype: :py:class:`v1_10_3.web.vo.NetworkLatencyTest`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/network/test/latency/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -63,10 +58,9 @@ def get_all(engine):
     Returns the list of previously executed tests.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_1.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of :py:class:`v1_11_1.web.vo.NetworkLatencyTest`
+    :type engine: :py:class:`delphixpy.v1_10_3.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_10_3.web.vo.NetworkLatencyTest`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/network/test/latency"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -78,12 +72,11 @@ def delete(engine, ref):
     Delete the specified NetworkLatencyTest object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_1.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_1.web.objects.Network
+    :type engine: :py:class:`delphixpy.v1_10_3.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_10_3.web.objects.Network
         LatencyTest.NetworkLatencyTest` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/network/test/latency/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
