@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,27 +17,21 @@
 """
 Package "selfservice.datasource"
 """
-API_VERSION = "1.11.10"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_10 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_10_4 import response_validator
 
 def get(engine, ref):
     """
     Retrieve the specified JSDataSource object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_4.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_10.web.objects.JSDataSource.JSDataSource`
+        :py:class:`delphixpy.v1_10_4.web.objects.JSDataSource.JSDataSource`
         object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_10.web.vo.JSDataSource`
+    :rtype: :py:class:`v1_10_4.web.vo.JSDataSource`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/datasource/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -50,16 +43,15 @@ def get_all(engine, data_layout=None, container=None):
     Lists the Self-Service data sources in the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_4.delphix_engine.DelphixEngine`
     :param data_layout: List the sources associated with the given data layout
         reference.
-    :type data_layout: ``TEXT_TYPE``
+    :type data_layout: ``str``
     :param container: List the source associated with the given container
         reference.
-    :type container: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_11_10.web.vo.JSDataSource`
+    :type container: ``str``
+    :rtype: ``list`` of :py:class:`v1_10_4.web.vo.JSDataSource`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/datasource"
     query_params = {"dataLayout": data_layout, "container": container}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -76,15 +68,14 @@ def update(engine, ref, js_data_source=None):
     Update the specified JSDataSource object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_4.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_10.web.objects.JSDataSource.JSDataSource`
+        :py:class:`delphixpy.v1_10_4.web.objects.JSDataSource.JSDataSource`
         object
     :type ref: ``str``
     :param js_data_source: Payload object.
-    :type js_data_source: :py:class:`v1_11_10.web.vo.JSDataSource`
+    :type js_data_source: :py:class:`v1_10_4.web.vo.JSDataSource`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/datasource/%s" % ref
     response = engine.post(url, js_data_source.to_dict(dirty=True) if js_data_source else None)
     result = response_validator.validate(response, engine)
@@ -98,13 +89,12 @@ def data_timestamps(engine, js_source_data_timestamp_parameters):
     layout.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_4.delphix_engine.DelphixEngine`
     :param js_source_data_timestamp_parameters: Payload object.
     :type js_source_data_timestamp_parameters:
-        :py:class:`v1_11_10.web.vo.JSSourceDataTimestampParameters`
-    :rtype: ``list`` of :py:class:`v1_11_10.web.vo.JSSourceDataTimestamp`
+        :py:class:`v1_10_4.web.vo.JSSourceDataTimestampParameters`
+    :rtype: ``list`` of :py:class:`v1_10_4.web.vo.JSSourceDataTimestamp`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/datasource/dataTimestamps"
     response = engine.post(url, js_source_data_timestamp_parameters.to_dict(dirty=True) if js_source_data_timestamp_parameters else None)
     result = response_validator.validate(response, engine)
