@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,28 +17,22 @@
 """
 Package "timezone"
 """
-API_VERSION = "1.10.5"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_10_5 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_10_4 import response_validator
 
 def get_all(engine, date=None):
     """
     Lists all of the supported time zones.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_10_5.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_4.delphix_engine.DelphixEngine`
     :param date: The offset of this time zone from UTC is calculated at this
         date. If Daylight Saving Time is in effect at the specified date, the
         offset value is adjusted with the amount of daylight saving. If no date
         is specified then a default time of now is used.
-    :type date: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_10_5.web.vo.TimeZone`
+    :type date: ``str``
+    :rtype: ``list`` of :py:class:`v1_10_4.web.vo.TimeZone`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/timezone"
     query_params = {"date": date}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
