@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,26 +17,20 @@
 """
 Package "environment.windows.clusternode"
 """
-API_VERSION = "1.8.0"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_8_0 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_10_5 import response_validator
 
 def get(engine, ref):
     """
     Retrieve the specified WindowsClusterNode object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_0.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_8_0.web.objects.WindowsC
-        lusterNode.WindowsClusterNode` object
+    :type engine: :py:class:`delphixpy.v1_10_5.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_10_5.web.objects.Windows
+        ClusterNode.WindowsClusterNode` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_8_0.web.vo.WindowsClusterNode`
+    :rtype: :py:class:`v1_10_5.web.vo.WindowsClusterNode`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/windows/clusternode/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -49,13 +42,12 @@ def get_all(engine, cluster=None):
     Returns a list of nodes filtered by cluster.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_5.delphix_engine.DelphixEngine`
     :param cluster: A reference to the Windows cluster environment this node
         belongs to.
-    :type cluster: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_8_0.web.vo.WindowsClusterNode`
+    :type cluster: ``str``
+    :rtype: ``list`` of :py:class:`v1_10_5.web.vo.WindowsClusterNode`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/windows/clusternode"
     query_params = {"cluster": cluster}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
