@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,19 +17,16 @@
 """
 Package "service.sso"
 """
-API_VERSION = "1.11.13"
-
-from delphixpy.v1_11_13 import response_validator
+from delphixpy.v1_10_5 import response_validator
 
 def get(engine):
     """
     Retrieve the specified SsoConfig object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_13.delphix_engine.DelphixEngine`
-    :rtype: :py:class:`v1_11_13.web.vo.SsoConfig`
+    :type engine: :py:class:`delphixpy.v1_10_5.delphix_engine.DelphixEngine`
+    :rtype: :py:class:`v1_10_5.web.vo.SsoConfig`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/sso"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -42,11 +38,10 @@ def set(engine, sso_config=None):
     Update the specified SsoConfig object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_13.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_5.delphix_engine.DelphixEngine`
     :param sso_config: Payload object.
-    :type sso_config: :py:class:`v1_11_13.web.vo.SsoConfig`
+    :type sso_config: :py:class:`v1_10_5.web.vo.SsoConfig`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/sso"
     response = engine.post(url, sso_config.to_dict(dirty=True) if sso_config else None)
     result = response_validator.validate(response, engine)
@@ -59,13 +54,12 @@ def sso_readiness(engine):
     satisfied.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_13.delphix_engine.DelphixEngine`
-    :rtype: ``TEXT_TYPE``
+    :type engine: :py:class:`delphixpy.v1_10_5.delphix_engine.DelphixEngine`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/sso/ssoReadiness"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
