@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,27 +17,21 @@
 """
 Package "transformation"
 """
-API_VERSION = "1.11.5"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_5 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_10_5 import response_validator
 
 def get(engine, ref):
     """
     Retrieve the specified Transformation object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_5.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_5.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_5.web.objects.Transformation.Transformation`
+        :py:class:`delphixpy.v1_10_5.web.objects.Transformation.Transformation`
         object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_5.web.vo.Transformation`
+    :rtype: :py:class:`v1_10_5.web.vo.Transformation`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/transformation/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -50,16 +43,15 @@ def get_all(engine, container=None, parent_container=None):
     Returns a list of all transformations on the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_5.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_5.delphix_engine.DelphixEngine`
     :param container: Return the transformation responsible for the given
         container reference.
-    :type container: ``TEXT_TYPE``
+    :type container: ``str``
     :param parent_container: List the transformations that have been created
         against the provided container.
-    :type parent_container: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_11_5.web.vo.Transformation`
+    :type parent_container: ``str``
+    :rtype: ``list`` of :py:class:`v1_10_5.web.vo.Transformation`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/transformation"
     query_params = {"container": container, "parentContainer": parent_container}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -76,15 +68,14 @@ def update(engine, ref, transformation=None):
     Update the specified Transformation object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_5.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_5.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_5.web.objects.Transformation.Transformation`
+        :py:class:`delphixpy.v1_10_5.web.objects.Transformation.Transformation`
         object
     :type ref: ``str``
     :param transformation: Payload object.
-    :type transformation: :py:class:`v1_11_5.web.vo.Transformation`
+    :type transformation: :py:class:`v1_10_5.web.vo.Transformation`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/transformation/%s" % ref
     response = engine.post(url, transformation.to_dict(dirty=True) if transformation else None)
     result = response_validator.validate(response, engine)
@@ -96,16 +87,15 @@ def apply(engine, ref, timeflow_point_parameters):
     Apply a transformation.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_5.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_5.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_5.web.objects.Transformation.Transformation`
+        :py:class:`delphixpy.v1_10_5.web.objects.Transformation.Transformation`
         object
     :type ref: ``str``
     :param timeflow_point_parameters: Payload object.
     :type timeflow_point_parameters:
-        :py:class:`v1_11_5.web.vo.TimeflowPointParameters`
+        :py:class:`v1_10_5.web.vo.TimeflowPointParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/transformation/%s/apply" % ref
     response = engine.post(url, timeflow_point_parameters.to_dict(dirty=True) if timeflow_point_parameters else None)
     result = response_validator.validate(response, engine)
