@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,44 +17,37 @@
 """
 Package "environment.oracle.listener"
 """
-API_VERSION = "1.9.0"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_9_0 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_10_6 import response_validator
 
 def create(engine, oracle_listener=None):
     """
     Create a new OracleListener object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
     :param oracle_listener: Payload object.
-    :type oracle_listener: :py:class:`v1_9_0.web.vo.OracleListener`
-    :rtype: ``TEXT_TYPE``
+    :type oracle_listener: :py:class:`v1_10_6.web.vo.OracleListener`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/oracle/listener"
     response = engine.post(url, oracle_listener.to_dict(dirty=True) if oracle_listener else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified OracleListener object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_9_0.web.objects.OracleListener.OracleListener`
+        :py:class:`delphixpy.v1_10_6.web.objects.OracleListener.OracleListener`
         object
     :type ref: ``str``
-    :rtype: :py:class:`v1_9_0.web.vo.OracleListener`
+    :rtype: :py:class:`v1_10_6.web.vo.OracleListener`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/oracle/listener/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -67,16 +59,15 @@ def get_all(engine, type=None, environment=None):
     Returns a list of listeners within the environment or the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
     :param type: Restrict listeners to type. *(permitted values:
         OracleNodeListener, OracleScanListener)*
-    :type type: ``TEXT_TYPE``
+    :type type: ``str``
     :param environment: Restrict listeners belonging to the specified
         environment.
-    :type environment: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_9_0.web.vo.OracleListener`
+    :type environment: ``str``
+    :rtype: ``list`` of :py:class:`v1_10_6.web.vo.OracleListener`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/oracle/listener"
     query_params = {"type": type, "environment": environment}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -93,15 +84,14 @@ def update(engine, ref, oracle_listener=None):
     Update the specified OracleListener object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_9_0.web.objects.OracleListener.OracleListener`
+        :py:class:`delphixpy.v1_10_6.web.objects.OracleListener.OracleListener`
         object
     :type ref: ``str``
     :param oracle_listener: Payload object.
-    :type oracle_listener: :py:class:`v1_9_0.web.vo.OracleListener`
+    :type oracle_listener: :py:class:`v1_10_6.web.vo.OracleListener`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/oracle/listener/%s" % ref
     response = engine.post(url, oracle_listener.to_dict(dirty=True) if oracle_listener else None)
     result = response_validator.validate(response, engine)
@@ -113,13 +103,12 @@ def delete(engine, ref):
     Delete the specified OracleListener object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_9_0.web.objects.OracleListener.OracleListener`
+        :py:class:`delphixpy.v1_10_6.web.objects.OracleListener.OracleListener`
         object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/oracle/listener/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
