@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,22 +17,19 @@
 """
 Package "replication.serializationpoint"
 """
-API_VERSION = "1.8.0"
-
-from delphixpy.v1_8_0 import response_validator
+from delphixpy.v1_10_6 import response_validator
 
 def get(engine, ref):
     """
     Retrieve the specified SerializationPoint object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_0.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_8_0.web.objects.Serializ
-        ationPoint.SerializationPoint` object
+    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_10_6.web.objects.Seriali
+        zationPoint.SerializationPoint` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_8_0.web.vo.SerializationPoint`
+    :rtype: :py:class:`v1_10_6.web.vo.SerializationPoint`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/replication/serializationpoint/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -45,10 +41,9 @@ def get_all(engine):
     List SerializationPoint objects on the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_0.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of :py:class:`v1_8_0.web.vo.SerializationPoint`
+    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_10_6.web.vo.SerializationPoint`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/replication/serializationpoint"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
