@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,39 +17,35 @@
 """
 Package "source.operationTemplate"
 """
-API_VERSION = "1.11.15"
-
-from delphixpy.v1_11_15 import response_validator
+from delphixpy.v1_10_6 import response_validator
 
 def create(engine, operation_template=None):
     """
     Create a new OperationTemplate object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_15.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
     :param operation_template: Payload object.
-    :type operation_template: :py:class:`v1_11_15.web.vo.OperationTemplate`
-    :rtype: ``TEXT_TYPE``
+    :type operation_template: :py:class:`v1_10_6.web.vo.OperationTemplate`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/source/operationTemplate"
     response = engine.post(url, operation_template.to_dict(dirty=True) if operation_template else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified OperationTemplate object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_15.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_15.web.objects.Operat
-        ionTemplate.OperationTemplate` object
+    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_10_6.web.objects.Operati
+        onTemplate.OperationTemplate` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_15.web.vo.OperationTemplate`
+    :rtype: :py:class:`v1_10_6.web.vo.OperationTemplate`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/source/operationTemplate/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -62,10 +57,9 @@ def get_all(engine):
     Lists templates available in the Delphix Engine.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_15.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of :py:class:`v1_11_15.web.vo.OperationTemplate`
+    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_10_6.web.vo.OperationTemplate`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/source/operationTemplate"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -77,14 +71,13 @@ def update(engine, ref, operation_template=None):
     Update the specified OperationTemplate object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_15.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_15.web.objects.Operat
-        ionTemplate.OperationTemplate` object
+    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_10_6.web.objects.Operati
+        onTemplate.OperationTemplate` object
     :type ref: ``str``
     :param operation_template: Payload object.
-    :type operation_template: :py:class:`v1_11_15.web.vo.OperationTemplate`
+    :type operation_template: :py:class:`v1_10_6.web.vo.OperationTemplate`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/source/operationTemplate/%s" % ref
     response = engine.post(url, operation_template.to_dict(dirty=True) if operation_template else None)
     result = response_validator.validate(response, engine)
@@ -96,12 +89,11 @@ def delete(engine, ref):
     Delete the specified OperationTemplate object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_15.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_15.web.objects.Operat
-        ionTemplate.OperationTemplate` object
+    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_10_6.web.objects.Operati
+        onTemplate.OperationTemplate` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/source/operationTemplate/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
