@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,41 +17,37 @@
 """
 Package "storage.test"
 """
-API_VERSION = "1.11.8"
-
-from delphixpy.v1_11_8 import response_validator
+from delphixpy.v1_10_6 import response_validator
 
 def create(engine, storage_test_parameters=None):
     """
     Create a new StorageTest object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_8.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
     :param storage_test_parameters: Payload object.
     :type storage_test_parameters:
-        :py:class:`v1_11_8.web.vo.StorageTestParameters`
-    :rtype: ``TEXT_TYPE``
+        :py:class:`v1_10_6.web.vo.StorageTestParameters`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/storage/test"
     response = engine.post(url, storage_test_parameters.to_dict(dirty=True) if storage_test_parameters else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified StorageTest object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_8.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_8.web.objects.StorageTest.StorageTest`
+        :py:class:`delphixpy.v1_10_6.web.objects.StorageTest.StorageTest`
         object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_8.web.vo.StorageTest`
+    :rtype: :py:class:`v1_10_6.web.vo.StorageTest`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/storage/test/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -64,10 +59,9 @@ def get_all(engine):
     Returns the list of previously executed tests.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_8.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of :py:class:`v1_11_8.web.vo.StorageTest`
+    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_10_6.web.vo.StorageTest`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/storage/test"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -79,13 +73,12 @@ def delete(engine, ref):
     Delete the specified StorageTest object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_8.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_8.web.objects.StorageTest.StorageTest`
+        :py:class:`delphixpy.v1_10_6.web.objects.StorageTest.StorageTest`
         object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/storage/test/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -97,17 +90,16 @@ def result(engine, ref):
     Retrieve the text result of the storage test.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_8.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_8.web.objects.StorageTest.StorageTest`
+        :py:class:`delphixpy.v1_10_6.web.objects.StorageTest.StorageTest`
         object
     :type ref: ``str``
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/storage/test/%s/result" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
