@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,13 +17,8 @@
 """
 Package "usage"
 """
-API_VERSION = "1.11.14"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_14 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_11_1 import response_validator
 
 def aggregate_ingested_size(engine, start_date=None, end_date=None):
     """
@@ -34,14 +28,13 @@ def aggregate_ingested_size(engine, start_date=None, end_date=None):
     last collection time until now.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_14.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_1.delphix_engine.DelphixEngine`
     :param start_date: Start time at which this information was sampled.
-    :type start_date: ``TEXT_TYPE``
+    :type start_date: ``str``
     :param end_date: End time at which this information was sampled.
-    :type end_date: ``TEXT_TYPE``
-    :rtype: :py:class:`v1_11_14.web.vo.EngineAggregateIngestedSize`
+    :type end_date: ``str``
+    :rtype: :py:class:`v1_11_1.web.vo.EngineAggregateIngestedSize`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/usage/aggregateIngestedSize"
     query_params = {"startDate": start_date, "endDate": end_date}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
