@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,43 +17,36 @@
 """
 Package "theme"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_16 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_11_10 import response_validator
 
 def create(engine, theme=None):
     """
     Create a new Theme object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_16.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
     :param theme: Payload object.
-    :type theme: :py:class:`v1_11_16.web.vo.Theme`
-    :rtype: ``TEXT_TYPE``
+    :type theme: :py:class:`v1_11_10.web.vo.Theme`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/theme"
     response = engine.post(url, theme.to_dict(dirty=True) if theme else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified Theme object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_16.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_16.web.objects.Theme.Theme` object
+        :py:class:`delphixpy.v1_11_10.web.objects.Theme.Theme` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_16.web.vo.Theme`
+    :rtype: :py:class:`v1_11_10.web.vo.Theme`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/theme/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -66,16 +58,15 @@ def get_all(engine, page_size=None, page_offset=None, active=None):
     Returns the list of themes.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_16.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
     :param page_size: Limit the number of check results returned.
     :type page_size: ``int``
     :param page_offset: Offset within result list, in units of pageSize chunks.
     :type page_offset: ``int``
     :param active: Decides whether or not to only return active theme.
     :type active: ``bool``
-    :rtype: ``list`` of :py:class:`v1_11_16.web.vo.Theme`
+    :rtype: ``list`` of :py:class:`v1_11_10.web.vo.Theme`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/theme"
     query_params = {"pageSize": page_size, "pageOffset": page_offset, "active": active}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -92,14 +83,13 @@ def update(engine, ref, theme=None):
     Update the specified Theme object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_16.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_16.web.objects.Theme.Theme` object
+        :py:class:`delphixpy.v1_11_10.web.objects.Theme.Theme` object
     :type ref: ``str``
     :param theme: Payload object.
-    :type theme: :py:class:`v1_11_16.web.vo.Theme`
+    :type theme: :py:class:`v1_11_10.web.vo.Theme`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/theme/%s" % ref
     response = engine.post(url, theme.to_dict(dirty=True) if theme else None)
     result = response_validator.validate(response, engine)
@@ -111,12 +101,11 @@ def delete(engine, ref):
     Delete the specified Theme object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_16.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_16.web.objects.Theme.Theme` object
+        :py:class:`delphixpy.v1_11_10.web.objects.Theme.Theme` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/theme/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -128,12 +117,11 @@ def set_active_theme(engine, theme_reference_parameter=None):
     Sets a theme as active. Passing null reference resets active themes.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_16.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
     :param theme_reference_parameter: Payload object.
     :type theme_reference_parameter:
-        :py:class:`v1_11_16.web.vo.ThemeReferenceParameter`
+        :py:class:`v1_11_10.web.vo.ThemeReferenceParameter`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/theme/setActiveTheme"
     response = engine.post(url, theme_reference_parameter.to_dict(dirty=True) if theme_reference_parameter else None)
     result = response_validator.validate(response, engine)
