@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,26 +17,20 @@
 """
 Package "job"
 """
-API_VERSION = "1.11.7"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_7 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_11_11 import response_validator
 
 def get(engine, ref):
     """
     Retrieve the specified Job object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_7.web.objects.Job.Job` object
+        :py:class:`delphixpy.v1_11_11.web.objects.Job.Job` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_7.web.vo.Job`
+    :rtype: :py:class:`v1_11_11.web.vo.Job`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/job/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -49,19 +42,19 @@ def get_all(engine, job_state=None, job_type=None, target=None, from_date=None,
     Returns a list of jobs in the system. Jobs are listed in start time order.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
     :param job_state: Limit jobs to those in the specified job state.
         *(permitted values: RUNNING, SUSPENDED, CANCELED, COMPLETED, FAILED)*
-    :type job_state: ``TEXT_TYPE``
+    :type job_state: ``str``
     :param job_type: Limit jobs to those with the specified job type.
-    :type job_type: ``TEXT_TYPE``
+    :type job_type: ``str``
     :param target: Limit jobs to those affecting a particular object on the
         system. The target is the object reference for the target in question.
-    :type target: ``TEXT_TYPE``
+    :type target: ``str``
     :param from_date: Filters out jobs older than this date.
-    :type from_date: ``TEXT_TYPE``
+    :type from_date: ``str``
     :param to_date: Filters out jobs newer than this date.
-    :type to_date: ``TEXT_TYPE``
+    :type to_date: ``str``
     :param page_size: Limit the number of jobs returned.
     :type page_size: ``int``
     :param page_offset: Page offset within job list.
@@ -70,12 +63,11 @@ def get_all(engine, job_state=None, job_type=None, target=None, from_date=None,
     :type add_events: ``bool``
     :param search_text: Limit search results to only include jobs that contain
         the searchText.
-    :type search_text: ``TEXT_TYPE``
+    :type search_text: ``str``
     :param max_total: The upper bound for calculation of total job count.
     :type max_total: ``int``
-    :rtype: ``list`` of :py:class:`v1_11_7.web.vo.Job`
+    :rtype: ``list`` of :py:class:`v1_11_11.web.vo.Job`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/job"
     query_params = {"jobState": job_state, "jobType": job_type, "target": target, "fromDate": from_date, "toDate": to_date, "pageSize": page_size, "pageOffset": page_offset, "addEvents": add_events, "searchText": search_text, "maxTotal": max_total}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -92,14 +84,13 @@ def update(engine, ref, job=None):
     Update the specified Job object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_7.web.objects.Job.Job` object
+        :py:class:`delphixpy.v1_11_11.web.objects.Job.Job` object
     :type ref: ``str``
     :param job: Payload object.
-    :type job: :py:class:`v1_11_7.web.vo.Job`
+    :type job: :py:class:`v1_11_11.web.vo.Job`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/job/%s" % ref
     response = engine.post(url, job.to_dict(dirty=True) if job else None)
     result = response_validator.validate(response, engine)
@@ -111,12 +102,11 @@ def cancel(engine, ref):
     Cancel the specified job.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_7.web.objects.Job.Job` object
+        :py:class:`delphixpy.v1_11_11.web.objects.Job.Job` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/job/%s/cancel" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -128,12 +118,11 @@ def suspend(engine, ref):
     Suspend the specified job.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_7.web.objects.Job.Job` object
+        :py:class:`delphixpy.v1_11_11.web.objects.Job.Job` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/job/%s/suspend" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -145,12 +134,11 @@ def resume(engine, ref):
     Resume the specified job.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_7.web.objects.Job.Job` object
+        :py:class:`delphixpy.v1_11_11.web.objects.Job.Job` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/job/%s/resume" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
