@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,39 +17,35 @@
 """
 Package "service.ldap.server"
 """
-API_VERSION = "1.5.0"
-
-from delphixpy.v1_5_0 import response_validator
+from delphixpy.v1_11_11 import response_validator
 
 def create(engine, ldap_server=None):
     """
     Create a new LdapServer object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
     :param ldap_server: Payload object.
-    :type ldap_server: :py:class:`v1_5_0.web.vo.LdapServer`
-    :rtype: ``TEXT_TYPE``
+    :type ldap_server: :py:class:`v1_11_11.web.vo.LdapServer`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/ldap/server"
     response = engine.post(url, ldap_server.to_dict(dirty=True) if ldap_server else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified LdapServer object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_5_0.web.objects.LdapServer.LdapServer` object
+        :py:class:`delphixpy.v1_11_11.web.objects.LdapServer.LdapServer` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_5_0.web.vo.LdapServer`
+    :rtype: :py:class:`v1_11_11.web.vo.LdapServer`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/ldap/server/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -62,10 +57,9 @@ def get_all(engine):
     List LdapServer objects on the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of :py:class:`v1_5_0.web.vo.LdapServer`
+    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_11_11.web.vo.LdapServer`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/ldap/server"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -77,14 +71,13 @@ def update(engine, ref, ldap_server=None):
     Update the specified LdapServer object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_5_0.web.objects.LdapServer.LdapServer` object
+        :py:class:`delphixpy.v1_11_11.web.objects.LdapServer.LdapServer` object
     :type ref: ``str``
     :param ldap_server: Payload object.
-    :type ldap_server: :py:class:`v1_5_0.web.vo.LdapServer`
+    :type ldap_server: :py:class:`v1_11_11.web.vo.LdapServer`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/ldap/server/%s" % ref
     response = engine.post(url, ldap_server.to_dict(dirty=True) if ldap_server else None)
     result = response_validator.validate(response, engine)
@@ -96,12 +89,11 @@ def delete(engine, ref):
     Delete the specified LdapServer object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_5_0.web.objects.LdapServer.LdapServer` object
+        :py:class:`delphixpy.v1_11_11.web.objects.LdapServer.LdapServer` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/ldap/server/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -113,11 +105,10 @@ def test(engine, ldap_server=None):
     Test the LDAP server by anonymous login.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
     :param ldap_server: Payload object.
-    :type ldap_server: :py:class:`v1_5_0.web.vo.LdapServer`
+    :type ldap_server: :py:class:`v1_11_11.web.vo.LdapServer`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/ldap/server/test"
     response = engine.post(url, ldap_server.to_dict(dirty=True) if ldap_server else None)
     result = response_validator.validate(response, engine)
