@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,26 +17,20 @@
 """
 Package "system.upgradeCheckResult"
 """
-API_VERSION = "1.11.6"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_6 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_11_11 import response_validator
 
 def get(engine, ref):
     """
     Retrieve the specified UpgradeCheckResult object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_6.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_6.web.objects.Upgrade
-        CheckResult.UpgradeCheckResult` object
+    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_11_11.web.objects.Upgrad
+        eCheckResult.UpgradeCheckResult` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_6.web.vo.UpgradeCheckResult`
+    :rtype: :py:class:`v1_11_11.web.vo.UpgradeCheckResult`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/system/upgradeCheckResult/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -49,25 +42,24 @@ def get_all(engine, version=None, status=None, page_size=None, page_offset=None,
     Returns the list of all the check results that match the given criteria.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_6.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
     :param version: The reference to the Delphix version associated with this
         verification check.
-    :type version: ``TEXT_TYPE``
+    :type version: ``str``
     :param status: The status of the upgrade check result. *(permitted values:
         ACTIVE, IGNORED, RESOLVED)*
-    :type status: ``TEXT_TYPE``
+    :type status: ``str``
     :param page_size: Limit the number of check results returned.
     :type page_size: ``int``
     :param page_offset: Offset within result list, in units of pageSize chunks.
     :type page_offset: ``int``
     :param sort_by: Search results are sorted by the field provided.
         *(permitted values: SEVERITY, TITLE, VERSION, STATUS)*
-    :type sort_by: ``TEXT_TYPE``
+    :type sort_by: ``str``
     :param ascending: True if results are to be returned in ascending order.
     :type ascending: ``bool``
-    :rtype: ``list`` of :py:class:`v1_11_6.web.vo.UpgradeCheckResult`
+    :rtype: ``list`` of :py:class:`v1_11_11.web.vo.UpgradeCheckResult`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/system/upgradeCheckResult"
     query_params = {"version": version, "status": status, "pageSize": page_size, "pageOffset": page_offset, "sortBy": sort_by, "ascending": ascending}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -85,12 +77,11 @@ def ignore(engine, ref):
     verifications.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_6.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_6.web.objects.Upgrade
-        CheckResult.UpgradeCheckResult` object
+    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_11_11.web.objects.Upgrad
+        eCheckResult.UpgradeCheckResult` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/system/upgradeCheckResult/%s/ignore" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -103,12 +94,11 @@ def resolve(engine, ref):
     requirements remain unmet.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_6.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_6.web.objects.Upgrade
-        CheckResult.UpgradeCheckResult` object
+    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_11_11.web.objects.Upgrad
+        eCheckResult.UpgradeCheckResult` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/system/upgradeCheckResult/%s/resolve" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -120,12 +110,11 @@ def reset(engine, ref):
     Resets this check result, clearing its ignored or resolved status.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_6.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_6.web.objects.Upgrade
-        CheckResult.UpgradeCheckResult` object
+    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_11_11.web.objects.Upgrad
+        eCheckResult.UpgradeCheckResult` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/system/upgradeCheckResult/%s/reset" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -137,12 +126,11 @@ def resolve_selected(engine, resolve_or_ignore_selected_checks_parameters):
     Marks selected check results as resolved.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_6.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
     :param resolve_or_ignore_selected_checks_parameters: Payload object.
     :type resolve_or_ignore_selected_checks_parameters:
-        :py:class:`v1_11_6.web.vo.ResolveOrIgnoreSelectedChecksParameters`
+        :py:class:`v1_11_11.web.vo.ResolveOrIgnoreSelectedChecksParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/system/upgradeCheckResult/resolveSelected"
     response = engine.post(url, resolve_or_ignore_selected_checks_parameters.to_dict(dirty=True) if resolve_or_ignore_selected_checks_parameters else None)
     result = response_validator.validate(response, engine)
@@ -154,12 +142,11 @@ def ignore_selected(engine, resolve_or_ignore_selected_checks_parameters):
     Marks selected check results as ignored.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_6.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
     :param resolve_or_ignore_selected_checks_parameters: Payload object.
     :type resolve_or_ignore_selected_checks_parameters:
-        :py:class:`v1_11_6.web.vo.ResolveOrIgnoreSelectedChecksParameters`
+        :py:class:`v1_11_11.web.vo.ResolveOrIgnoreSelectedChecksParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/system/upgradeCheckResult/ignoreSelected"
     response = engine.post(url, resolve_or_ignore_selected_checks_parameters.to_dict(dirty=True) if resolve_or_ignore_selected_checks_parameters else None)
     result = response_validator.validate(response, engine)
@@ -171,12 +158,11 @@ def reset_selected(engine, resolve_or_ignore_selected_checks_parameters):
     Reset selected check results to active.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_6.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
     :param resolve_or_ignore_selected_checks_parameters: Payload object.
     :type resolve_or_ignore_selected_checks_parameters:
-        :py:class:`v1_11_6.web.vo.ResolveOrIgnoreSelectedChecksParameters`
+        :py:class:`v1_11_11.web.vo.ResolveOrIgnoreSelectedChecksParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/system/upgradeCheckResult/resetSelected"
     response = engine.post(url, resolve_or_ignore_selected_checks_parameters.to_dict(dirty=True) if resolve_or_ignore_selected_checks_parameters else None)
     result = response_validator.validate(response, engine)
@@ -189,12 +175,11 @@ def resolve_version_checks(engine, upgrade_version_checks_parameter):
     INFORMATIONAL checks.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_6.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
     :param upgrade_version_checks_parameter: Payload object.
     :type upgrade_version_checks_parameter:
-        :py:class:`v1_11_6.web.vo.UpgradeVersionChecksParameter`
+        :py:class:`v1_11_11.web.vo.UpgradeVersionChecksParameter`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/system/upgradeCheckResult/resolveVersionChecks"
     response = engine.post(url, upgrade_version_checks_parameter.to_dict(dirty=True) if upgrade_version_checks_parameter else None)
     result = response_validator.validate(response, engine)
@@ -206,12 +191,11 @@ def ignore_version_checks(engine, upgrade_version_checks_parameter):
     Marks check results as ignored for a version. Only affects WARNING checks.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_6.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
     :param upgrade_version_checks_parameter: Payload object.
     :type upgrade_version_checks_parameter:
-        :py:class:`v1_11_6.web.vo.UpgradeVersionChecksParameter`
+        :py:class:`v1_11_11.web.vo.UpgradeVersionChecksParameter`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/system/upgradeCheckResult/ignoreVersionChecks"
     response = engine.post(url, upgrade_version_checks_parameter.to_dict(dirty=True) if upgrade_version_checks_parameter else None)
     result = response_validator.validate(response, engine)
@@ -223,12 +207,11 @@ def reset_version_checks(engine, upgrade_version_checks_parameter):
     Reset check results to active for a version.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_6.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
     :param upgrade_version_checks_parameter: Payload object.
     :type upgrade_version_checks_parameter:
-        :py:class:`v1_11_6.web.vo.UpgradeVersionChecksParameter`
+        :py:class:`v1_11_11.web.vo.UpgradeVersionChecksParameter`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/system/upgradeCheckResult/resetVersionChecks"
     response = engine.post(url, upgrade_version_checks_parameter.to_dict(dirty=True) if upgrade_version_checks_parameter else None)
     result = response_validator.validate(response, engine)
