@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,13 +17,8 @@
 """
 Package "network.dsp.autotune"
 """
-API_VERSION = "1.11.16"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_16 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_11_12 import response_validator
 
 def run(engine, dsp_autotuner_parameters):
     """
@@ -32,12 +26,11 @@ def run(engine, dsp_autotuner_parameters):
     target.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_16.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_12.delphix_engine.DelphixEngine`
     :param dsp_autotuner_parameters: Payload object.
     :type dsp_autotuner_parameters:
-        :py:class:`v1_11_16.web.vo.DSPAutotunerParameters`
+        :py:class:`v1_11_12.web.vo.DSPAutotunerParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/network/dsp/autotune/run"
     response = engine.post(url, dsp_autotuner_parameters.to_dict(dirty=True) if dsp_autotuner_parameters else None)
     result = response_validator.validate(response, engine)
@@ -50,13 +43,12 @@ def show_saved_best_params(engine, target_address=None):
     address.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_16.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_12.delphix_engine.DelphixEngine`
     :param target_address: Target address for which to display the saved best
         parameters.
-    :type target_address: ``TEXT_TYPE``
-    :rtype: ``TEXT_TYPE``
+    :type target_address: ``str``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/network/dsp/autotune/showSavedBestParams"
     query_params = {"targetAddress": target_address}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -66,5 +58,5 @@ def show_saved_best_params(engine, target_address=None):
     response = engine.get(url)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
