@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,40 +17,36 @@
 """
 Package "service.snmp.v3.usm"
 """
-API_VERSION = "1.11.7"
-
-from delphixpy.v1_11_7 import response_validator
+from delphixpy.v1_11_12 import response_validator
 
 def create(engine, snmpv3_usm_user_config=None):
     """
     Create a new SNMPV3USMUserConfig object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_12.delphix_engine.DelphixEngine`
     :param snmpv3_usm_user_config: Payload object.
     :type snmpv3_usm_user_config:
-        :py:class:`v1_11_7.web.vo.SNMPV3USMUserConfig`
-    :rtype: ``TEXT_TYPE``
+        :py:class:`v1_11_12.web.vo.SNMPV3USMUserConfig`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/snmp/v3/usm"
     response = engine.post(url, snmpv3_usm_user_config.to_dict(dirty=True) if snmpv3_usm_user_config else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified SNMPV3USMUserConfig object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_7.web.objects.SNMPV3U
-        SMUserConfig.SNMPV3USMUserConfig` object
+    :type engine: :py:class:`delphixpy.v1_11_12.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_11_12.web.objects.SNMPV3
+        USMUserConfig.SNMPV3USMUserConfig` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_7.web.vo.SNMPV3USMUserConfig`
+    :rtype: :py:class:`v1_11_12.web.vo.SNMPV3USMUserConfig`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/snmp/v3/usm/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -63,10 +58,9 @@ def get_all(engine):
     Lists SNMP User Security Model users.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of :py:class:`v1_11_7.web.vo.SNMPV3USMUserConfig`
+    :type engine: :py:class:`delphixpy.v1_11_12.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_11_12.web.vo.SNMPV3USMUserConfig`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/snmp/v3/usm"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -78,15 +72,14 @@ def update(engine, ref, snmpv3_usm_user_config=None):
     Update the specified SNMPV3USMUserConfig object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_7.web.objects.SNMPV3U
-        SMUserConfig.SNMPV3USMUserConfig` object
+    :type engine: :py:class:`delphixpy.v1_11_12.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_11_12.web.objects.SNMPV3
+        USMUserConfig.SNMPV3USMUserConfig` object
     :type ref: ``str``
     :param snmpv3_usm_user_config: Payload object.
     :type snmpv3_usm_user_config:
-        :py:class:`v1_11_7.web.vo.SNMPV3USMUserConfig`
+        :py:class:`v1_11_12.web.vo.SNMPV3USMUserConfig`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/snmp/v3/usm/%s" % ref
     response = engine.post(url, snmpv3_usm_user_config.to_dict(dirty=True) if snmpv3_usm_user_config else None)
     result = response_validator.validate(response, engine)
@@ -98,12 +91,11 @@ def delete(engine, ref):
     Delete the specified SNMPV3USMUserConfig object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_7.web.objects.SNMPV3U
-        SMUserConfig.SNMPV3USMUserConfig` object
+    :type engine: :py:class:`delphixpy.v1_11_12.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_11_12.web.objects.SNMPV3
+        USMUserConfig.SNMPV3USMUserConfig` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/snmp/v3/usm/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
