@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,40 +17,36 @@
 """
 Package "repository.template"
 """
-API_VERSION = "1.11.11"
-
-from delphixpy.v1_11_11 import response_validator
+from delphixpy.v1_11_13 import response_validator
 
 def create(engine, source_repository_template=None):
     """
     Create a new SourceRepositoryTemplate object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_13.delphix_engine.DelphixEngine`
     :param source_repository_template: Payload object.
     :type source_repository_template:
-        :py:class:`v1_11_11.web.vo.SourceRepositoryTemplate`
-    :rtype: ``TEXT_TYPE``
+        :py:class:`v1_11_13.web.vo.SourceRepositoryTemplate`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/repository/template"
     response = engine.post(url, source_repository_template.to_dict(dirty=True) if source_repository_template else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified SourceRepositoryTemplate object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_11.web.objects.Source
+    :type engine: :py:class:`delphixpy.v1_11_13.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_11_13.web.objects.Source
         RepositoryTemplate.SourceRepositoryTemplate` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_11.web.vo.SourceRepositoryTemplate`
+    :rtype: :py:class:`v1_11_13.web.vo.SourceRepositoryTemplate`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/repository/template/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -63,10 +58,9 @@ def get_all(engine):
     Returns the list of repository templates.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of :py:class:`v1_11_11.web.vo.SourceRepositoryTemplate`
+    :type engine: :py:class:`delphixpy.v1_11_13.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_11_13.web.vo.SourceRepositoryTemplate`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/repository/template"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -78,15 +72,14 @@ def update(engine, ref, source_repository_template=None):
     Update the specified SourceRepositoryTemplate object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_11.web.objects.Source
+    :type engine: :py:class:`delphixpy.v1_11_13.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_11_13.web.objects.Source
         RepositoryTemplate.SourceRepositoryTemplate` object
     :type ref: ``str``
     :param source_repository_template: Payload object.
     :type source_repository_template:
-        :py:class:`v1_11_11.web.vo.SourceRepositoryTemplate`
+        :py:class:`v1_11_13.web.vo.SourceRepositoryTemplate`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/repository/template/%s" % ref
     response = engine.post(url, source_repository_template.to_dict(dirty=True) if source_repository_template else None)
     result = response_validator.validate(response, engine)
@@ -98,12 +91,11 @@ def delete(engine, ref):
     Delete the specified SourceRepositoryTemplate object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_11.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_11.web.objects.Source
+    :type engine: :py:class:`delphixpy.v1_11_13.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_11_13.web.objects.Source
         RepositoryTemplate.SourceRepositoryTemplate` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/repository/template/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
