@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,23 +17,17 @@
 """
 Package "capacity.heldspace"
 """
-API_VERSION = "1.11.6"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_6 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_11_14 import response_validator
 
 def get_all(engine):
     """
     Lists HeldSpace in the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_6.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of :py:class:`v1_11_6.web.vo.HeldSpaceCapacityData`
+    :type engine: :py:class:`delphixpy.v1_11_14.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_11_14.web.vo.HeldSpaceCapacityData`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/capacity/heldspace"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -46,13 +39,12 @@ def deletion_dependencies(engine, storage_container=None):
     Returns instructions on how to free up this HeldSpace.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_6.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_14.delphix_engine.DelphixEngine`
     :param storage_container: The unique ID of the retained space to get
         deletion instructions for.
-    :type storage_container: ``TEXT_TYPE``
-    :rtype: :py:class:`v1_11_6.web.vo.DeletionDependency`
+    :type storage_container: ``str``
+    :rtype: :py:class:`v1_11_14.web.vo.DeletionDependency`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/capacity/heldspace/deletionDependencies"
     query_params = {"storageContainer": storage_container}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
