@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,19 +17,16 @@
 """
 Package "storage.scrub"
 """
-API_VERSION = "1.10.5"
-
-from delphixpy.v1_10_5 import response_validator
+from delphixpy.v1_11_15 import response_validator
 
 def get(engine):
     """
     Retrieve the specified ScrubStatus object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_10_5.delphix_engine.DelphixEngine`
-    :rtype: :py:class:`v1_10_5.web.vo.ScrubStatus`
+    :type engine: :py:class:`delphixpy.v1_11_15.delphix_engine.DelphixEngine`
+    :rtype: :py:class:`v1_11_15.web.vo.ScrubStatus`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/storage/scrub"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -42,9 +38,8 @@ def start(engine):
     Initiate a scrub of all data on the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_10_5.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_15.delphix_engine.DelphixEngine`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/storage/scrub/start"
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -56,12 +51,37 @@ def stop(engine):
     Terminate a scrub.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_10_5.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_15.delphix_engine.DelphixEngine`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/storage/scrub/stop"
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
     return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
 
+def pause(engine):
+    """
+    Pause a scrub.
+
+    :param engine: The Delphix Engine
+    :type engine: :py:class:`delphixpy.v1_11_15.delphix_engine.DelphixEngine`
+    """
+    url = "/resources/json/delphix/storage/scrub/pause"
+    response = engine.post(url, None)
+    result = response_validator.validate(response, engine)
+    raw_result = getattr(engine, 'raw_result', False)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
+
+def resume(engine):
+    """
+    Resume a paused scrub.
+
+    :param engine: The Delphix Engine
+    :type engine: :py:class:`delphixpy.v1_11_15.delphix_engine.DelphixEngine`
+    """
+    url = "/resources/json/delphix/storage/scrub/resume"
+    response = engine.post(url, None)
+    result = response_validator.validate(response, engine)
+    raw_result = getattr(engine, 'raw_result', False)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
+
