@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,26 +17,20 @@
 """
 Package "system.verification.reports"
 """
-API_VERSION = "1.11.4"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_4 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_11_15 import response_validator
 
 def get(engine, ref):
     """
     Retrieve the specified UpgradeVerificationReport object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_4.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_4.web.objects.Upgrade
-        VerificationReport.UpgradeVerificationReport` object
+    :type engine: :py:class:`delphixpy.v1_11_15.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_11_15.web.objects.Upgrad
+        eVerificationReport.UpgradeVerificationReport` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_4.web.vo.UpgradeVerificationReport`
+    :rtype: :py:class:`v1_11_15.web.vo.UpgradeVerificationReport`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/system/verification/reports/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -49,22 +42,21 @@ def get_all(engine, version=None, page_size=None, page_offset=None, sort_by=None
     List UpgradeVerificationReport objects on the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_4.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_15.delphix_engine.DelphixEngine`
     :param version: The reference to the Delphix version associated with this
         verification report.
-    :type version: ``TEXT_TYPE``
+    :type version: ``str``
     :param page_size: Limit the number of report results returned.
     :type page_size: ``int``
     :param page_offset: Offset within result list, in units of pageSize chunks.
     :type page_offset: ``int``
     :param sort_by: Search results are sorted by the field provided.
         *(permitted values: VERSION, VERIFICATION_VERSION)*
-    :type sort_by: ``TEXT_TYPE``
+    :type sort_by: ``str``
     :param ascending: True if results are to be returned in ascending order.
     :type ascending: ``bool``
-    :rtype: ``list`` of :py:class:`v1_11_4.web.vo.UpgradeVerificationReport`
+    :rtype: ``list`` of :py:class:`v1_11_15.web.vo.UpgradeVerificationReport`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/system/verification/reports"
     query_params = {"version": version, "pageSize": page_size, "pageOffset": page_offset, "sortBy": sort_by, "ascending": ascending}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
