@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,8 +17,6 @@
 """
 Package "netty"
 """
-API_VERSION = "1.11.16"
-
 from delphixpy.v1_11_16 import response_validator
 
 def get(engine):
@@ -30,7 +27,6 @@ def get(engine):
     :type engine: :py:class:`delphixpy.v1_11_16.delphix_engine.DelphixEngine`
     :rtype: :py:class:`v1_11_16.web.vo.NettyVersionInfo`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/netty"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -43,12 +39,11 @@ def switch_version(engine):
 
     :param engine: The Delphix Engine
     :type engine: :py:class:`delphixpy.v1_11_16.delphix_engine.DelphixEngine`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/netty/switchVersion"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
