@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,26 +17,20 @@
 """
 Package "replication.targetstate"
 """
-API_VERSION = "1.5.3"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_5_3 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_11_16 import response_validator
 
 def get(engine, ref):
     """
     Retrieve the specified ReplicationTargetState object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_5_3.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_5_3.web.objects.Replicat
-        ionTargetState.ReplicationTargetState` object
+    :type engine: :py:class:`delphixpy.v1_11_16.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_11_16.web.objects.Replic
+        ationTargetState.ReplicationTargetState` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_5_3.web.vo.ReplicationTargetState`
+    :rtype: :py:class:`v1_11_16.web.vo.ReplicationTargetState`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/replication/targetstate/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -49,10 +42,9 @@ def get_all(engine):
     List ReplicationTargetState objects on the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_5_3.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of :py:class:`v1_5_3.web.vo.ReplicationTargetState`
+    :type engine: :py:class:`delphixpy.v1_11_16.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_11_16.web.vo.ReplicationTargetState`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/replication/targetstate"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -64,12 +56,11 @@ def get_by_namespace(engine, namespace=None):
     Find the replication target state associated with a given namespace.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_5_3.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_16.delphix_engine.DelphixEngine`
     :param namespace: Namespace object reference.
-    :type namespace: ``TEXT_TYPE``
-    :rtype: :py:class:`v1_5_3.web.vo.ReplicationTargetState`
+    :type namespace: ``str``
+    :rtype: :py:class:`v1_11_16.web.vo.ReplicationTargetState`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/replication/targetstate/getByNamespace"
     query_params = {"namespace": namespace}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
