@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,38 +17,32 @@
 """
 Package "selfservice.usage.container"
 """
-API_VERSION = "1.11.14"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_14 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_11_16 import response_validator
 
 def list_container_usage_data(engine, data_container=None, template=None, user=None):
     """
     Lists the usage breakdown for data containers.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_14.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_16.delphix_engine.DelphixEngine`
     :param data_container: If passed in, this query parameter restricts the API
         to only return the usage information for the given data container. This
         parameter is mutually exclusive with the "template" and "user"
         parameters.
-    :type data_container: ``TEXT_TYPE``
+    :type data_container: ``str``
     :param template: If passed in, this query parameter restricts the API to
         only return the usage information for all of the data containers from
         the given data template. This parameter is mutually exclusive with the
         "dataContainer" and "user" parameters.
-    :type template: ``TEXT_TYPE``
+    :type template: ``str``
     :param user: If passed in, this query parameter restricts the API to only
         return the usage information for all of the data containers owned by
         the given user. This parameter is mutually exclusive with the
         "dataContainer" and "template" parameters.
-    :type user: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_11_14.web.vo.JSContainerUsageData`
+    :type user: ``str``
+    :rtype: ``list`` of :py:class:`v1_11_16.web.vo.JSContainerUsageData`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/usage/container/listContainerUsageData"
     query_params = {"dataContainer": data_container, "template": template, "user": user}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
