@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,39 +17,35 @@
 """
 Package "role"
 """
-API_VERSION = "1.11.5"
-
-from delphixpy.v1_11_5 import response_validator
+from delphixpy.v1_11_17 import response_validator
 
 def create(engine, role=None):
     """
     Create a new Role object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_5.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_17.delphix_engine.DelphixEngine`
     :param role: Payload object.
-    :type role: :py:class:`v1_11_5.web.vo.Role`
-    :rtype: ``TEXT_TYPE``
+    :type role: :py:class:`v1_11_17.web.vo.Role`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/role"
     response = engine.post(url, role.to_dict(dirty=True) if role else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified Role object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_5.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_17.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_5.web.objects.Role.Role` object
+        :py:class:`delphixpy.v1_11_17.web.objects.Role.Role` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_5.web.vo.Role`
+    :rtype: :py:class:`v1_11_17.web.vo.Role`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/role/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -62,10 +57,9 @@ def get_all(engine):
     Lists roles available in the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_5.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of :py:class:`v1_11_5.web.vo.Role`
+    :type engine: :py:class:`delphixpy.v1_11_17.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_11_17.web.vo.Role`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/role"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -77,14 +71,13 @@ def update(engine, ref, role=None):
     Update the specified Role object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_5.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_17.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_5.web.objects.Role.Role` object
+        :py:class:`delphixpy.v1_11_17.web.objects.Role.Role` object
     :type ref: ``str``
     :param role: Payload object.
-    :type role: :py:class:`v1_11_5.web.vo.Role`
+    :type role: :py:class:`v1_11_17.web.vo.Role`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/role/%s" % ref
     response = engine.post(url, role.to_dict(dirty=True) if role else None)
     result = response_validator.validate(response, engine)
@@ -96,12 +89,11 @@ def delete(engine, ref):
     Delete the specified Role object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_5.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_17.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_5.web.objects.Role.Role` object
+        :py:class:`delphixpy.v1_11_17.web.objects.Role.Role` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/role/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -113,10 +105,9 @@ def auditor_role(engine):
     Returns the auditor role.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_5.delphix_engine.DelphixEngine`
-    :rtype: :py:class:`v1_11_5.web.vo.Role`
+    :type engine: :py:class:`delphixpy.v1_11_17.delphix_engine.DelphixEngine`
+    :rtype: :py:class:`v1_11_17.web.vo.Role`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/role/auditorRole"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -128,10 +119,9 @@ def provisioner_role(engine):
     Returns the provisioner role.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_5.delphix_engine.DelphixEngine`
-    :rtype: :py:class:`v1_11_5.web.vo.Role`
+    :type engine: :py:class:`delphixpy.v1_11_17.delphix_engine.DelphixEngine`
+    :rtype: :py:class:`v1_11_17.web.vo.Role`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/role/provisionerRole"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -143,10 +133,9 @@ def owner_role(engine):
     Returns the owner role.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_5.delphix_engine.DelphixEngine`
-    :rtype: :py:class:`v1_11_5.web.vo.Role`
+    :type engine: :py:class:`delphixpy.v1_11_17.delphix_engine.DelphixEngine`
+    :rtype: :py:class:`v1_11_17.web.vo.Role`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/role/ownerRole"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -158,10 +147,9 @@ def jet_stream_user_role(engine):
     Returns the Self-Service user role.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_5.delphix_engine.DelphixEngine`
-    :rtype: :py:class:`v1_11_5.web.vo.Role`
+    :type engine: :py:class:`delphixpy.v1_11_17.delphix_engine.DelphixEngine`
+    :rtype: :py:class:`v1_11_17.web.vo.Role`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/role/jetStreamUserRole"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -173,10 +161,9 @@ def self_service_user_role(engine):
     Returns the Self-Service user role.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_5.delphix_engine.DelphixEngine`
-    :rtype: :py:class:`v1_11_5.web.vo.Role`
+    :type engine: :py:class:`delphixpy.v1_11_17.delphix_engine.DelphixEngine`
+    :rtype: :py:class:`v1_11_17.web.vo.Role`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/role/selfServiceUserRole"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
