@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,26 +17,20 @@
 """
 Package "selfservice.usagedata.operationduration"
 """
-API_VERSION = "1.11.14"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_14 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_11_17 import response_validator
 
 def get(engine, ref):
     """
     Retrieve the specified JSDailyOperationDuration object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_14.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_14.web.objects.JSDail
+    :type engine: :py:class:`delphixpy.v1_11_17.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_11_17.web.objects.JSDail
         yOperationDuration.JSDailyOperationDuration` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_14.web.vo.JSDailyOperationDuration`
+    :rtype: :py:class:`v1_11_17.web.vo.JSDailyOperationDuration`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/usagedata/operationduration/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -50,13 +43,12 @@ def get_all(engine, usage_object=None):
     operations related to a single object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_14.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_17.delphix_engine.DelphixEngine`
     :param usage_object: Restrict usage data to that related to a specific
         object.
-    :type usage_object: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_11_14.web.vo.JSDailyOperationDuration`
+    :type usage_object: ``str``
+    :rtype: ``list`` of :py:class:`v1_11_17.web.vo.JSDailyOperationDuration`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/usagedata/operationduration"
     query_params = {"usageObject": usage_object}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
