@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,45 +17,49 @@
 """
 Package "web"
 """
-API_VERSION = "1.8.2"
-
-from . import source
-from . import sourceconfig
-from . import registration
-from . import delphix
-from . import environment
-from . import snapshot
-from . import host
-from . import service
-from . import database
-from . import permission
-from . import group
-from . import timeflow
-from . import action
-from . import timezone
-from . import alert
-from . import fault
-from . import job
-from . import toolkit
-from . import about
-from . import jetstream
-from . import namespace
-from . import objects
-from . import user
-from . import replication
-from . import storage
-from . import policy
-from . import connectivity
-from . import system
-from . import repository
-from . import analytics
 from . import transformation
-from . import domain
-from . import maskingjob
-from . import authorization
-from . import capacity
+from . import action
+from . import passwordPolicy
 from . import notification
-from . import data
-from . import session
+from . import sourceconfig
+from . import authorization
+from . import about
+from . import source
+from . import registration
+from . import toolkit
+from . import fault
+from . import user
+from . import repository
+from . import namespace
 from . import role
+from . import host
+from . import storage
+from . import connectivity
+from . import maskingjob
+from . import session
+from . import selfservice
+from . import service
+from . import policy
+from . import job
+from . import timeflow
+from . import data
+from . import permission
+from . import snapshot
+from . import alert
+from . import objects
+from . import replication
+from . import environment
+from . import repave
+from . import delphix
+from . import usage
+from . import license
+from . import analytics
+from . import system
 from . import network
+from . import database
+from . import timezone
+from . import domain
+from . import osadmin
+from . import theme
+from . import group
+from . import capacity
