@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,26 +17,20 @@
 """
 Package "replication.sourcestate"
 """
-API_VERSION = "1.8.2"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_8_2 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_11_18 import response_validator
 
 def get(engine, ref):
     """
     Retrieve the specified ReplicationSourceState object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_2.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_8_2.web.objects.Replicat
-        ionSourceState.ReplicationSourceState` object
+    :type engine: :py:class:`delphixpy.v1_11_18.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_11_18.web.objects.Replic
+        ationSourceState.ReplicationSourceState` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_8_2.web.vo.ReplicationSourceState`
+    :rtype: :py:class:`v1_11_18.web.vo.ReplicationSourceState`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/replication/sourcestate/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -49,10 +42,9 @@ def get_all(engine):
     List ReplicationSourceState objects on the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_2.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of :py:class:`v1_8_2.web.vo.ReplicationSourceState`
+    :type engine: :py:class:`delphixpy.v1_11_18.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_11_18.web.vo.ReplicationSourceState`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/replication/sourcestate"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -64,12 +56,11 @@ def get_by_spec(engine, spec=None):
     Find the replication source state associated with a given replication spec.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_2.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_18.delphix_engine.DelphixEngine`
     :param spec: Replication spec object reference.
-    :type spec: ``TEXT_TYPE``
-    :rtype: :py:class:`v1_8_2.web.vo.ReplicationSourceState`
+    :type spec: ``str``
+    :rtype: :py:class:`v1_11_18.web.vo.ReplicationSourceState`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/replication/sourcestate/getBySpec"
     query_params = {"spec": spec}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
