@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,40 +17,36 @@
 """
 Package "service.insight.splunkHec"
 """
-API_VERSION = "1.11.4"
-
-from delphixpy.v1_11_4 import response_validator
+from delphixpy.v1_11_18 import response_validator
 
 def create(engine, splunk_hec_config=None):
     """
     Create a new SplunkHecConfig object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_4.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_18.delphix_engine.DelphixEngine`
     :param splunk_hec_config: Payload object.
-    :type splunk_hec_config: :py:class:`v1_11_4.web.vo.SplunkHecConfig`
-    :rtype: ``TEXT_TYPE``
+    :type splunk_hec_config: :py:class:`v1_11_18.web.vo.SplunkHecConfig`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/insight/splunkHec"
     response = engine.post(url, splunk_hec_config.to_dict(dirty=True) if splunk_hec_config else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified SplunkHecConfig object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_4.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_18.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_4.web.objects.SplunkHecConfig.SplunkHecConfi
-        g` object
+        :py:class:`delphixpy.v1_11_18.web.objects.SplunkHecConfig.SplunkHecConf
+        ig` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_4.web.vo.SplunkHecConfig`
+    :rtype: :py:class:`v1_11_18.web.vo.SplunkHecConfig`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/insight/splunkHec/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -63,10 +58,9 @@ def get_all(engine):
     List SplunkHecConfig objects on the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_4.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of :py:class:`v1_11_4.web.vo.SplunkHecConfig`
+    :type engine: :py:class:`delphixpy.v1_11_18.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_11_18.web.vo.SplunkHecConfig`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/insight/splunkHec"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -78,15 +72,14 @@ def update(engine, ref, splunk_hec_config=None):
     Update the specified SplunkHecConfig object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_4.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_18.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_4.web.objects.SplunkHecConfig.SplunkHecConfi
-        g` object
+        :py:class:`delphixpy.v1_11_18.web.objects.SplunkHecConfig.SplunkHecConf
+        ig` object
     :type ref: ``str``
     :param splunk_hec_config: Payload object.
-    :type splunk_hec_config: :py:class:`v1_11_4.web.vo.SplunkHecConfig`
+    :type splunk_hec_config: :py:class:`v1_11_18.web.vo.SplunkHecConfig`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/insight/splunkHec/%s" % ref
     response = engine.post(url, splunk_hec_config.to_dict(dirty=True) if splunk_hec_config else None)
     result = response_validator.validate(response, engine)
@@ -98,13 +91,12 @@ def delete(engine, ref):
     Delete the specified SplunkHecConfig object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_4.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_18.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_4.web.objects.SplunkHecConfig.SplunkHecConfi
-        g` object
+        :py:class:`delphixpy.v1_11_18.web.objects.SplunkHecConfig.SplunkHecConf
+        ig` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/insight/splunkHec/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -117,15 +109,14 @@ def test(engine, splunk_hec_config=None):
     specified index or indexes.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_4.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_18.delphix_engine.DelphixEngine`
     :param splunk_hec_config: Payload object.
-    :type splunk_hec_config: :py:class:`v1_11_4.web.vo.SplunkHecConfig`
-    :rtype: ``TEXT_TYPE``
+    :type splunk_hec_config: :py:class:`v1_11_18.web.vo.SplunkHecConfig`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/insight/splunkHec/test"
     response = engine.post(url, splunk_hec_config.to_dict(dirty=True) if splunk_hec_config else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
