@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,44 +17,37 @@
 """
 Package "service.userPaths"
 """
-API_VERSION = "1.11.0"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_0 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_11_18 import response_validator
 
 def create(engine, user_path_storage=None):
     """
     Create a new UserPathStorage object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_18.delphix_engine.DelphixEngine`
     :param user_path_storage: Payload object.
-    :type user_path_storage: :py:class:`v1_11_0.web.vo.UserPathStorage`
-    :rtype: ``TEXT_TYPE``
+    :type user_path_storage: :py:class:`v1_11_18.web.vo.UserPathStorage`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/userPaths"
     response = engine.post(url, user_path_storage.to_dict(dirty=True) if user_path_storage else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified UserPathStorage object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_18.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_0.web.objects.UserPathStorage.UserPathStorag
-        e` object
+        :py:class:`delphixpy.v1_11_18.web.objects.UserPathStorage.UserPathStora
+        ge` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_0.web.vo.UserPathStorage`
+    :rtype: :py:class:`v1_11_18.web.vo.UserPathStorage`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/userPaths/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -67,13 +59,12 @@ def get_all(engine, pathtype=None):
     Returns the list of all the check results that match the given criteria.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_18.delphix_engine.DelphixEngine`
     :param pathtype: Type of path stored. *(permitted values:
         UPGRADE_STAGING_LOC)*
-    :type pathtype: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_11_0.web.vo.UserPathStorage`
+    :type pathtype: ``str``
+    :rtype: ``list`` of :py:class:`v1_11_18.web.vo.UserPathStorage`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/userPaths"
     query_params = {"pathtype": pathtype}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -90,15 +81,14 @@ def update(engine, ref, user_path_storage=None):
     Update the specified UserPathStorage object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_18.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_0.web.objects.UserPathStorage.UserPathStorag
-        e` object
+        :py:class:`delphixpy.v1_11_18.web.objects.UserPathStorage.UserPathStora
+        ge` object
     :type ref: ``str``
     :param user_path_storage: Payload object.
-    :type user_path_storage: :py:class:`v1_11_0.web.vo.UserPathStorage`
+    :type user_path_storage: :py:class:`v1_11_18.web.vo.UserPathStorage`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/userPaths/%s" % ref
     response = engine.post(url, user_path_storage.to_dict(dirty=True) if user_path_storage else None)
     result = response_validator.validate(response, engine)
@@ -110,13 +100,12 @@ def delete(engine, ref):
     Delete the specified UserPathStorage object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_18.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_0.web.objects.UserPathStorage.UserPathStorag
-        e` object
+        :py:class:`delphixpy.v1_11_18.web.objects.UserPathStorage.UserPathStora
+        ge` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/userPaths/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
