@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,38 +17,32 @@
 """
 Package "system.verification.reports.steps"
 """
-API_VERSION = "1.11.5"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_5 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_11_18 import response_validator
 
 def get_all(engine, version=None, run_status=None, page_size=None, page_offset=None, sort_by=None, ascending=None):
     """
     List UpgradeVerificationSteps objects on the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_5.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_18.delphix_engine.DelphixEngine`
     :param version: The reference to the Delphix version associated with this
         verification steps.
-    :type version: ``TEXT_TYPE``
+    :type version: ``str``
     :param run_status: Result status of the step. *(permitted values: SUCCESS,
         FAILURE, SKIPPED)*
-    :type run_status: ``TEXT_TYPE``
+    :type run_status: ``str``
     :param page_size: Limit the number of step results returned.
     :type page_size: ``int``
     :param page_offset: Offset within result list, in units of pageSize chunks.
     :type page_offset: ``int``
     :param sort_by: Search results are sorted by the field provided.
         *(permitted values: RUN_STATUS, CLASS_NAME, START_TIMESTAMP, DURATION)*
-    :type sort_by: ``TEXT_TYPE``
+    :type sort_by: ``str``
     :param ascending: True if results are to be returned in ascending order.
     :type ascending: ``bool``
-    :rtype: ``list`` of :py:class:`v1_11_5.web.vo.UpgradeVerificationSteps`
+    :rtype: ``list`` of :py:class:`v1_11_18.web.vo.UpgradeVerificationSteps`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/system/verification/reports/steps"
     query_params = {"version": version, "runStatus": run_status, "pageSize": page_size, "pageOffset": page_offset, "sortBy": sort_by, "ascending": ascending}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
