@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,26 +17,21 @@
 """
 Package "environment.windows.failoverclusterrepositoryinstance"
 """
-API_VERSION = "1.5.3"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_5_3 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_11_19 import response_validator
 
 def get_all(engine, repository=None):
     """
     Returns a list of instances filtered by SQL Server Failover Cluster.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_5_3.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_19.delphix_engine.DelphixEngine`
     :param repository: A reference to the SQL Server Failover Cluster
         repository this instance belongs to.
-    :type repository: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_5_3.web.vo.MSSqlFailoverClusterInstance`
+    :type repository: ``str``
+    :rtype: ``list`` of
+        :py:class:`v1_11_19.web.vo.MSSqlFailoverClusterInstance`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/windows/failoverclusterrepositoryinstance"
     query_params = {"repository": repository}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
