@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,23 +17,17 @@
 """
 Package "service.oauth2"
 """
-API_VERSION = "1.11.15"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_15 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_11_19 import response_validator
 
 def get(engine):
     """
     Retrieve the specified OAuth2Config object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_15.delphix_engine.DelphixEngine`
-    :rtype: :py:class:`v1_11_15.web.vo.OAuth2Config`
+    :type engine: :py:class:`delphixpy.v1_11_19.delphix_engine.DelphixEngine`
+    :rtype: :py:class:`v1_11_19.web.vo.OAuth2Config`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/oauth2"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -46,11 +39,10 @@ def set(engine, o_auth2_config=None):
     Update the specified OAuth2Config object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_15.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_19.delphix_engine.DelphixEngine`
     :param o_auth2_config: Payload object.
-    :type o_auth2_config: :py:class:`v1_11_15.web.vo.OAuth2Config`
+    :type o_auth2_config: :py:class:`v1_11_19.web.vo.OAuth2Config`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/oauth2"
     response = engine.post(url, o_auth2_config.to_dict(dirty=True) if o_auth2_config else None)
     result = response_validator.validate(response, engine)
@@ -62,14 +54,13 @@ def oauth2_readiness(engine, user_matching_field_type=None):
     Indicates whether the conditions for enabling OAuth2 are satisfied.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_15.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_19.delphix_engine.DelphixEngine`
     :param user_matching_field_type: Specify the user field that should be
         verified to confirm OAuth2 readiness. *(permitted values: NAME,
         EMAIL_ADDRESS, PRINCIPAL)*
-    :type user_matching_field_type: ``TEXT_TYPE``
-    :rtype: ``TEXT_TYPE``
+    :type user_matching_field_type: ``str``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/oauth2/oauth2Readiness"
     query_params = {"userMatchingFieldType": user_matching_field_type}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -79,5 +70,5 @@ def oauth2_readiness(engine, user_matching_field_type=None):
     response = engine.get(url)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
