@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,39 +17,35 @@
 """
 Package "group"
 """
-API_VERSION = "1.11.6"
-
-from delphixpy.v1_11_6 import response_validator
+from delphixpy.v1_11_20 import response_validator
 
 def create(engine, group=None):
     """
     Create a new Group object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_6.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_20.delphix_engine.DelphixEngine`
     :param group: Payload object.
-    :type group: :py:class:`v1_11_6.web.vo.Group`
-    :rtype: ``TEXT_TYPE``
+    :type group: :py:class:`v1_11_20.web.vo.Group`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/group"
     response = engine.post(url, group.to_dict(dirty=True) if group else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified Group object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_6.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_20.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_6.web.objects.Group.Group` object
+        :py:class:`delphixpy.v1_11_20.web.objects.Group.Group` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_6.web.vo.Group`
+    :rtype: :py:class:`v1_11_20.web.vo.Group`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/group/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -62,10 +57,9 @@ def get_all(engine):
     List Group objects on the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_6.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of :py:class:`v1_11_6.web.vo.Group`
+    :type engine: :py:class:`delphixpy.v1_11_20.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_11_20.web.vo.Group`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/group"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -77,14 +71,13 @@ def update(engine, ref, group=None):
     Update the specified Group object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_6.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_20.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_6.web.objects.Group.Group` object
+        :py:class:`delphixpy.v1_11_20.web.objects.Group.Group` object
     :type ref: ``str``
     :param group: Payload object.
-    :type group: :py:class:`v1_11_6.web.vo.Group`
+    :type group: :py:class:`v1_11_20.web.vo.Group`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/group/%s" % ref
     response = engine.post(url, group.to_dict(dirty=True) if group else None)
     result = response_validator.validate(response, engine)
@@ -96,15 +89,31 @@ def delete(engine, ref):
     Delete the specified Group object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_6.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_20.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_6.web.objects.Group.Group` object
+        :py:class:`delphixpy.v1_11_20.web.objects.Group.Group` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/group/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
     return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
 
+def lock(engine, ref):
+    """
+    Protects all sources in the group from deletion and other data-losing
+    actions. Cannot be undone.
+
+    :param engine: The Delphix Engine
+    :type engine: :py:class:`delphixpy.v1_11_20.delphix_engine.DelphixEngine`
+    :param ref: Reference to a
+        :py:class:`delphixpy.v1_11_20.web.objects.Group.Group` object
+    :type ref: ``str``
+    """
+    url = "/resources/json/delphix/group/%s/lock" % ref
+    response = engine.post(url, None)
+    result = response_validator.validate(response, engine)
+    raw_result = getattr(engine, 'raw_result', False)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
+
