@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,44 +17,37 @@
 """
 Package "passwordPolicy"
 """
-API_VERSION = "1.11.4"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_4 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_11_20 import response_validator
 
 def create(engine, password_policy=None):
     """
     Create a new PasswordPolicy object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_4.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_20.delphix_engine.DelphixEngine`
     :param password_policy: Payload object.
-    :type password_policy: :py:class:`v1_11_4.web.vo.PasswordPolicy`
-    :rtype: ``TEXT_TYPE``
+    :type password_policy: :py:class:`v1_11_20.web.vo.PasswordPolicy`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/passwordPolicy"
     response = engine.post(url, password_policy.to_dict(dirty=True) if password_policy else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified PasswordPolicy object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_4.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_20.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_4.web.objects.PasswordPolicy.PasswordPolicy`
-        object
+        :py:class:`delphixpy.v1_11_20.web.objects.PasswordPolicy.PasswordPolicy
+        ` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_4.web.vo.PasswordPolicy`
+    :rtype: :py:class:`v1_11_20.web.vo.PasswordPolicy`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/passwordPolicy/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -67,10 +59,9 @@ def get_all(engine):
     Lists password policies in the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_4.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of :py:class:`v1_11_4.web.vo.PasswordPolicy`
+    :type engine: :py:class:`delphixpy.v1_11_20.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_11_20.web.vo.PasswordPolicy`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/passwordPolicy"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -82,15 +73,14 @@ def update(engine, ref, password_policy=None):
     Update the specified PasswordPolicy object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_4.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_20.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_4.web.objects.PasswordPolicy.PasswordPolicy`
-        object
+        :py:class:`delphixpy.v1_11_20.web.objects.PasswordPolicy.PasswordPolicy
+        ` object
     :type ref: ``str``
     :param password_policy: Payload object.
-    :type password_policy: :py:class:`v1_11_4.web.vo.PasswordPolicy`
+    :type password_policy: :py:class:`v1_11_20.web.vo.PasswordPolicy`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/passwordPolicy/%s" % ref
     response = engine.post(url, password_policy.to_dict(dirty=True) if password_policy else None)
     result = response_validator.validate(response, engine)
@@ -102,13 +92,12 @@ def delete(engine, ref):
     Delete the specified PasswordPolicy object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_4.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_20.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_4.web.objects.PasswordPolicy.PasswordPolicy`
-        object
+        :py:class:`delphixpy.v1_11_20.web.objects.PasswordPolicy.PasswordPolicy
+        ` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/passwordPolicy/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -121,15 +110,14 @@ def current_requirements(engine):
     if the Delphix Engine has not been configured yet.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_4.delphix_engine.DelphixEngine`
-    :rtype: ``TEXT_TYPE``
+    :type engine: :py:class:`delphixpy.v1_11_20.delphix_engine.DelphixEngine`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/passwordPolicy/currentRequirements"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def change_current_password_policy(engine, change_current_password_policy_parameters):
     """
@@ -137,12 +125,11 @@ def change_current_password_policy(engine, change_current_password_policy_parame
     user type.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_4.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_20.delphix_engine.DelphixEngine`
     :param change_current_password_policy_parameters: Payload object.
     :type change_current_password_policy_parameters:
-        :py:class:`v1_11_4.web.vo.ChangeCurrentPasswordPolicyParameters`
+        :py:class:`v1_11_20.web.vo.ChangeCurrentPasswordPolicyParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/passwordPolicy/changeCurrentPasswordPolicy"
     response = engine.post(url, change_current_password_policy_parameters.to_dict(dirty=True) if change_current_password_policy_parameters else None)
     result = response_validator.validate(response, engine)
@@ -155,12 +142,11 @@ def current_password_policy(engine, user_type=None):
     type.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_4.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_20.delphix_engine.DelphixEngine`
     :param user_type: Type of user. *(permitted values: SYSTEM, DOMAIN)*
-    :type user_type: ``TEXT_TYPE``
-    :rtype: :py:class:`v1_11_4.web.vo.PasswordPolicy`
+    :type user_type: ``str``
+    :rtype: :py:class:`v1_11_20.web.vo.PasswordPolicy`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/passwordPolicy/currentPasswordPolicy"
     query_params = {"userType": user_type}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
