@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,32 +17,26 @@
 """
 Package "capacity.group.historical"
 """
-API_VERSION = "1.9.2"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_9_2 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_11_4 import response_validator
 
 def get_all(engine, group=None, start_date=None, end_date=None, resolution=None):
     """
     Lists historical capacity data for a particular group.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_2.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_4.delphix_engine.DelphixEngine`
     :param group: The group to list data for.
-    :type group: ``TEXT_TYPE``
+    :type group: ``str``
     :param start_date: Earliest date for which to list data.
-    :type start_date: ``TEXT_TYPE``
+    :type start_date: ``str``
     :param end_date: Latest date for which to list data.
-    :type end_date: ``TEXT_TYPE``
+    :type end_date: ``str``
     :param resolution: The time range each datapoint should represent, measured
         in seconds. This parameter is only meaningful if a group is specified.
     :type resolution: ``int``
-    :rtype: ``list`` of :py:class:`v1_9_2.web.vo.HistoricalGroupCapacityData`
+    :rtype: ``list`` of :py:class:`v1_11_4.web.vo.HistoricalGroupCapacityData`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/capacity/group/historical"
     query_params = {"group": group, "startDate": start_date, "endDate": end_date, "resolution": resolution}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
