@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,27 +17,21 @@
 """
 Package "selfservice.operation"
 """
-API_VERSION = "1.11.14"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_14 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_11_5 import response_validator
 
 def get(engine, ref):
     """
     Retrieve the specified JSOperation object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_14.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_5.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_14.web.objects.JSOperation.JSOperation`
+        :py:class:`delphixpy.v1_11_5.web.objects.JSOperation.JSOperation`
         object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_14.web.vo.JSOperation`
+    :rtype: :py:class:`v1_11_5.web.vo.JSOperation`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/operation/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -50,17 +43,17 @@ def get_all(engine, data_layout=None, branch=None, data_time=None, before_count=
     Lists the Self-Service action history for a data layout.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_14.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_5.delphix_engine.DelphixEngine`
     :param data_layout: Limit operations to the specific data layout. This
         option is mutually exclusive with the "branch" option.
-    :type data_layout: ``TEXT_TYPE``
+    :type data_layout: ``str``
     :param branch: Limit operations to the specified branch. This option is
         mutually exclusive with the "dataLayout" option.
-    :type branch: ``TEXT_TYPE``
+    :type branch: ``str``
     :param data_time: Limit operations that occurred around the specified
         "dataTime". "beforeCount" and "afterCount" should specify the number of
         events to be returned.
-    :type data_time: ``TEXT_TYPE``
+    :type data_time: ``str``
     :param before_count: The suggested maximum number of visible operations
         prior to "dataTime" that should be returned. If there are not
         sufficient events before additional events after may be returned.
@@ -72,14 +65,13 @@ def get_all(engine, data_layout=None, branch=None, data_time=None, before_count=
     :param data_start_time: Operations with "dataTime" after this value will be
         returned. Used with "dataEndTime" to return a set of operations between
         two dates.
-    :type data_start_time: ``TEXT_TYPE``
+    :type data_start_time: ``str``
     :param data_end_time: Operations with "dataTime" before this value will be
         returned. Used with "dataStartTime" to return a set of operations
         between two dates.
-    :type data_end_time: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_11_14.web.vo.JSOperation`
+    :type data_end_time: ``str``
+    :rtype: ``list`` of :py:class:`v1_11_5.web.vo.JSOperation`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/operation"
     query_params = {"dataLayout": data_layout, "branch": branch, "dataTime": data_time, "beforeCount": before_count, "afterCount": after_count, "dataStartTime": data_start_time, "dataEndTime": data_end_time}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -96,13 +88,12 @@ def endpoint(engine, js_operation_endpoint_parameters):
     Return the first and last operation for the specified parameters.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_14.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_5.delphix_engine.DelphixEngine`
     :param js_operation_endpoint_parameters: Payload object.
     :type js_operation_endpoint_parameters:
-        :py:class:`v1_11_14.web.vo.JSOperationEndpointParameters`
-    :rtype: :py:class:`v1_11_14.web.vo.JSOperationEndpoint`
+        :py:class:`v1_11_5.web.vo.JSOperationEndpointParameters`
+    :rtype: :py:class:`v1_11_5.web.vo.JSOperationEndpoint`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/operation/endpoint"
     response = engine.post(url, js_operation_endpoint_parameters.to_dict(dirty=True) if js_operation_endpoint_parameters else None)
     result = response_validator.validate(response, engine)
@@ -115,12 +106,11 @@ def list_operations_by_action(engine, action=None):
     action.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_14.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_5.delphix_engine.DelphixEngine`
     :param action: The given action.
-    :type action: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_11_14.web.vo.JSOperation`
+    :type action: ``str``
+    :rtype: ``list`` of :py:class:`v1_11_5.web.vo.JSOperation`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/operation/listOperationsByAction"
     query_params = {"action": action}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -137,12 +127,11 @@ def list_operations_by_job(engine, job=None):
     Return the list of operations spawned by the root action of the given job.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_14.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_5.delphix_engine.DelphixEngine`
     :param job: The given job.
-    :type job: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_11_14.web.vo.JSOperation`
+    :type job: ``str``
+    :rtype: ``list`` of :py:class:`v1_11_5.web.vo.JSOperation`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/operation/listOperationsByJob"
     query_params = {"job": job}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -160,12 +149,11 @@ def list_operations_by_template(engine, template=None):
     template.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_14.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_5.delphix_engine.DelphixEngine`
     :param template: The given template.
-    :type template: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_11_14.web.vo.JSOperation`
+    :type template: ``str``
+    :rtype: ``list`` of :py:class:`v1_11_5.web.vo.JSOperation`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/selfservice/operation/listOperationsByTemplate"
     query_params = {"template": template}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
