@@ -1,5 +1,5 @@
 # 
-# Copyright 2014, 2022 by Delphix
+# Copyright 2014, 2023 by Delphix
 # 
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 
 import time
 from contextlib import contextmanager
-from delphixpy.v1_11_6 import exceptions
+from delphixpy.v1_11_7 import exceptions
 
 VERBOSE_ENGINES = set()
 
@@ -28,7 +28,7 @@ def set_verbose(engine, verbose=True):
         VERBOSE_ENGINES.remove(engine.address)
 
 
-class JobMode(object):
+class JobMode:
     ASYNC = 'ASYNC'
     SYNC = 'SYNC'
 
@@ -54,7 +54,7 @@ def sync(engine):
 
 
 def wait(engine, job_ref):
-    from delphixpy.v1_11_6.web import job
+    from delphixpy.v1_11_7.web import job
     status = None
     event_counter = 0
     while True:
