@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,45 +17,38 @@
 """
 Package "authorization"
 """
-API_VERSION = "1.11.1"
-
-from delphixpy.v1_11_1.web.authorization import configuration
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_1 import response_validator
+from delphixpy.v1_11_7.web.authorization import configuration
+from urllib.parse import urlencode
+from delphixpy.v1_11_7 import response_validator
 
 def create(engine, authorization=None):
     """
     Create a new Authorization object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_1.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
     :param authorization: Payload object.
-    :type authorization: :py:class:`v1_11_1.web.vo.Authorization`
-    :rtype: ``TEXT_TYPE``
+    :type authorization: :py:class:`v1_11_7.web.vo.Authorization`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/authorization"
     response = engine.post(url, authorization.to_dict(dirty=True) if authorization else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified Authorization object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_1.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_1.web.objects.Authorization.Authorization`
+        :py:class:`delphixpy.v1_11_7.web.objects.Authorization.Authorization`
         object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_1.web.vo.Authorization`
+    :rtype: :py:class:`v1_11_7.web.vo.Authorization`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/authorization/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -68,16 +60,15 @@ def get_all(engine, user=None, target=None, effective=None):
     Lists authorizations granted in the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_1.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
     :param user: Lists permissions granted to the specified user.
-    :type user: ``TEXT_TYPE``
+    :type user: ``str``
     :param target: Lists the permissions granted on the specified object.
-    :type target: ``TEXT_TYPE``
+    :type target: ``str``
     :param effective: Also return inherited authorizations.
-    :type effective: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_11_1.web.vo.Authorization`
+    :type effective: ``str``
+    :rtype: ``list`` of :py:class:`v1_11_7.web.vo.Authorization`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/authorization"
     query_params = {"user": user, "target": target, "effective": effective}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -94,13 +85,12 @@ def delete(engine, ref):
     Delete the specified Authorization object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_1.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_1.web.objects.Authorization.Authorization`
+        :py:class:`delphixpy.v1_11_7.web.objects.Authorization.Authorization`
         object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/authorization/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -112,13 +102,12 @@ def filter_by_permission(engine, auth_filter_parameters):
     Filter a set of objects for which the user has the specified permission.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_1.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
     :param auth_filter_parameters: Payload object.
     :type auth_filter_parameters:
-        :py:class:`v1_11_1.web.vo.AuthFilterParameters`
-    :rtype: :py:class:`v1_11_1.web.vo.AuthFilterResult`
+        :py:class:`v1_11_7.web.vo.AuthFilterParameters`
+    :rtype: :py:class:`v1_11_7.web.vo.AuthFilterResult`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/authorization/filterByPermission"
     response = engine.post(url, auth_filter_parameters.to_dict(dirty=True) if auth_filter_parameters else None)
     result = response_validator.validate(response, engine)
@@ -130,13 +119,12 @@ def get_by_properties(engine, auth_get_by_properties_parameters):
     Find the authorization with given user, target, and role.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_1.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
     :param auth_get_by_properties_parameters: Payload object.
     :type auth_get_by_properties_parameters:
-        :py:class:`v1_11_1.web.vo.AuthGetByPropertiesParameters`
-    :rtype: :py:class:`v1_11_1.web.vo.Authorization`
+        :py:class:`v1_11_7.web.vo.AuthGetByPropertiesParameters`
+    :rtype: :py:class:`v1_11_7.web.vo.Authorization`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/authorization/getByProperties"
     response = engine.post(url, auth_get_by_properties_parameters.to_dict(dirty=True) if auth_get_by_properties_parameters else None)
     result = response_validator.validate(response, engine)
