@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,40 +17,36 @@
 """
 Package "service.passwordVault"
 """
-API_VERSION = "1.11.15"
-
-from delphixpy.v1_11_15 import response_validator
+from delphixpy.v1_11_7 import response_validator
 
 def create(engine, password_vault=None):
     """
     Create a new PasswordVault object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_15.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
     :param password_vault: Payload object.
-    :type password_vault: :py:class:`v1_11_15.web.vo.PasswordVault`
-    :rtype: ``TEXT_TYPE``
+    :type password_vault: :py:class:`v1_11_7.web.vo.PasswordVault`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/passwordVault"
     response = engine.post(url, password_vault.to_dict(dirty=True) if password_vault else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified PasswordVault object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_15.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_15.web.objects.PasswordVault.PasswordVault`
+        :py:class:`delphixpy.v1_11_7.web.objects.PasswordVault.PasswordVault`
         object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_15.web.vo.PasswordVault`
+    :rtype: :py:class:`v1_11_7.web.vo.PasswordVault`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/passwordVault/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -63,10 +58,9 @@ def get_all(engine):
     List PasswordVault objects on the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_15.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of :py:class:`v1_11_15.web.vo.PasswordVault`
+    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_11_7.web.vo.PasswordVault`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/passwordVault"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -78,15 +72,14 @@ def update(engine, ref, password_vault=None):
     Update the specified PasswordVault object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_15.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_15.web.objects.PasswordVault.PasswordVault`
+        :py:class:`delphixpy.v1_11_7.web.objects.PasswordVault.PasswordVault`
         object
     :type ref: ``str``
     :param password_vault: Payload object.
-    :type password_vault: :py:class:`v1_11_15.web.vo.PasswordVault`
+    :type password_vault: :py:class:`v1_11_7.web.vo.PasswordVault`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/passwordVault/%s" % ref
     response = engine.post(url, password_vault.to_dict(dirty=True) if password_vault else None)
     result = response_validator.validate(response, engine)
@@ -98,13 +91,12 @@ def delete(engine, ref):
     Delete the specified PasswordVault object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_15.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_15.web.objects.PasswordVault.PasswordVault`
+        :py:class:`delphixpy.v1_11_7.web.objects.PasswordVault.PasswordVault`
         object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/passwordVault/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -116,13 +108,12 @@ def validate(engine, ref):
     Tests connection to this password vault with the configured credentials.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_15.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_15.web.objects.PasswordVault.PasswordVault`
+        :py:class:`delphixpy.v1_11_7.web.objects.PasswordVault.PasswordVault`
         object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/passwordVault/%s/validate" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -134,12 +125,11 @@ def validate_vault(engine, password_vault_test_parameters=None):
     Tests connection to a password vault with the provided credentials.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_15.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
     :param password_vault_test_parameters: Payload object.
     :type password_vault_test_parameters:
-        :py:class:`v1_11_15.web.vo.PasswordVaultTestParameters`
+        :py:class:`v1_11_7.web.vo.PasswordVaultTestParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/passwordVault/validateVault"
     response = engine.post(url, password_vault_test_parameters.to_dict(dirty=True) if password_vault_test_parameters else None)
     result = response_validator.validate(response, engine)
@@ -152,13 +142,12 @@ def request_client_certificate_upload(engine, certificate_upload_parameters):
     certificate chain.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_15.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
     :param certificate_upload_parameters: Payload object.
     :type certificate_upload_parameters:
-        :py:class:`v1_11_15.web.vo.CertificateUploadParameters`
-    :rtype: :py:class:`v1_11_15.web.vo.FileUploadResult`
+        :py:class:`v1_11_7.web.vo.CertificateUploadParameters`
+    :rtype: :py:class:`v1_11_7.web.vo.FileUploadResult`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/passwordVault/requestClientCertificateUpload"
     response = engine.post(url, certificate_upload_parameters.to_dict(dirty=True) if certificate_upload_parameters else None)
     result = response_validator.validate(response, engine)
