@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,47 +17,40 @@
 """
 Package "environment"
 """
-API_VERSION = "1.11.14"
-
-from delphixpy.v1_11_14.web.environment import oracle
-from delphixpy.v1_11_14.web.environment import user
-from delphixpy.v1_11_14.web.environment import windows
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_14 import response_validator
+from delphixpy.v1_11_8.web.environment import user
+from delphixpy.v1_11_8.web.environment import oracle
+from delphixpy.v1_11_8.web.environment import windows
+from urllib.parse import urlencode
+from delphixpy.v1_11_8 import response_validator
 
 def create(engine, source_environment_create_parameters):
     """
     Create a new SourceEnvironment object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_14.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_8.delphix_engine.DelphixEngine`
     :param source_environment_create_parameters: Payload object.
     :type source_environment_create_parameters:
-        :py:class:`v1_11_14.web.vo.SourceEnvironmentCreateParameters`
-    :rtype: ``TEXT_TYPE``
+        :py:class:`v1_11_8.web.vo.SourceEnvironmentCreateParameters`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment"
     response = engine.post(url, source_environment_create_parameters.to_dict(dirty=True) if source_environment_create_parameters else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified SourceEnvironment object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_14.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_14.web.objects.Source
-        Environment.SourceEnvironment` object
+    :type engine: :py:class:`delphixpy.v1_11_8.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_11_8.web.objects.SourceE
+        nvironment.SourceEnvironment` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_14.web.vo.SourceEnvironment`
+    :rtype: :py:class:`v1_11_8.web.vo.SourceEnvironment`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -70,14 +62,13 @@ def get_all(engine, type=None):
     Returns the list of all source environments.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_14.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_8.delphix_engine.DelphixEngine`
     :param type: Filter the results based on the type of environment.
         *(permitted values: WindowsHostEnvironment, UnixHostEnvironment,
         ASEUnixHostEnvironment, OracleCluster)*
-    :type type: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_11_14.web.vo.SourceEnvironment`
+    :type type: ``str``
+    :rtype: ``list`` of :py:class:`v1_11_8.web.vo.SourceEnvironment`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment"
     query_params = {"type": type}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -94,14 +85,13 @@ def update(engine, ref, source_environment=None):
     Update the specified SourceEnvironment object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_14.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_14.web.objects.Source
-        Environment.SourceEnvironment` object
+    :type engine: :py:class:`delphixpy.v1_11_8.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_11_8.web.objects.SourceE
+        nvironment.SourceEnvironment` object
     :type ref: ``str``
     :param source_environment: Payload object.
-    :type source_environment: :py:class:`v1_11_14.web.vo.SourceEnvironment`
+    :type source_environment: :py:class:`v1_11_8.web.vo.SourceEnvironment`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/%s" % ref
     response = engine.post(url, source_environment.to_dict(dirty=True) if source_environment else None)
     result = response_validator.validate(response, engine)
@@ -113,12 +103,11 @@ def delete(engine, ref):
     Delete the specified SourceEnvironment object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_14.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_14.web.objects.Source
-        Environment.SourceEnvironment` object
+    :type engine: :py:class:`delphixpy.v1_11_8.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_11_8.web.objects.SourceE
+        nvironment.SourceEnvironment` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -130,12 +119,11 @@ def refresh(engine, ref):
     Refreshes the given environment.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_14.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_14.web.objects.Source
-        Environment.SourceEnvironment` object
+    :type engine: :py:class:`delphixpy.v1_11_8.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_11_8.web.objects.SourceE
+        nvironment.SourceEnvironment` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/%s/refresh" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -148,12 +136,11 @@ def enable(engine, ref):
     environments.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_14.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_14.web.objects.Source
-        Environment.SourceEnvironment` object
+    :type engine: :py:class:`delphixpy.v1_11_8.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_11_8.web.objects.SourceE
+        nvironment.SourceEnvironment` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/%s/enable" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -165,12 +152,11 @@ def disable(engine, ref):
     Disables the given environment.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_14.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_14.web.objects.Source
-        Environment.SourceEnvironment` object
+    :type engine: :py:class:`delphixpy.v1_11_8.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_11_8.web.objects.SourceE
+        nvironment.SourceEnvironment` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/%s/disable" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
