@@ -1,5 +1,5 @@
 # 
-# Copyright 2014, 2022 by Delphix
+# Copyright 2014, 2023 by Delphix
 # 
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -36,7 +36,7 @@ REFRESH_HTTP_CONNECTION_TIMEOUT = 0.5
 HTTP_SOCKET_TIMEOUT = 3
 
 
-class HttpClient(object):
+class HttpClient:
     """
     A wrapper around the standard HTTP module "httplib".
     """
@@ -79,7 +79,7 @@ class HttpClient(object):
     def _request(self, method, path, data, headers):
         if not headers:
             headers = {}
-        log = logging.getLogger("delphixpy.v1_10_2.http_client")
+        log = logging.getLogger("delphixpy.v1_11_9.http_client")
         if not path.startswith('/'):
             path = '/' + path
         try:
@@ -135,7 +135,7 @@ class HttpClient(object):
                 :data: The body of the response.
         :raises: `IOError` if the request failed.
         """
-        log = logging.getLogger("delphixpy.v1_10_2.http_client")
+        log = logging.getLogger("delphixpy.v1_11_9.http_client")
         log.debug("%s: GET(%s, %s)", self._address, path, headers)
         response = self._request("GET", path, None, headers)
         return self._repack_response(response)
@@ -154,7 +154,7 @@ class HttpClient(object):
                 :data: The body of the response.
         :raises: `IOError` if the request failed.
         """
-        log = logging.getLogger("delphixpy.v1_10_2.http_client")
+        log = logging.getLogger("delphixpy.v1_11_9.http_client")
         log.debug("%s: POST(%s, %s, %s)", self._address, path, data, headers)
         response = self._request("POST", path, data, headers)
         return self._repack_response(response)
@@ -178,4 +178,4 @@ class HttpsClient(HttpClient):
                     cls=self.__class__.__name__,
                     parent_cls="httplib.HTTPSConnection",
             ))
-        super(HttpsClient, self).__init__(address, https_connection)
\ No newline at end of file
+        super().__init__(address, https_connection)
\ No newline at end of file
