@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,27 +17,29 @@
 """
 Package "capacity.snapshot"
 """
-API_VERSION = "1.4.2"
+from urllib.parse import urlencode
+from delphixpy.v1_11_9 import response_validator
 
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_4_2 import response_validator
-
-def get_all(engine, container=None):
+def get_all(engine, container=None, namespace=None, page_size=None, page_offset=None):
     """
-    Lists consumers in the system.
+    Lists capacity metrics for all snapshots in the system sorted by snapshot
+    space usage decreasing.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_4_2.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_9.delphix_engine.DelphixEngine`
     :param container: The container to list snapshot data for.
-    :type container: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_4_2.web.vo.SnapshotCapacityData`
+    :type container: ``str``
+    :param namespace: The namespace to list snapshot data for. If null, will
+        limit returned snapshots to the default namespace.
+    :type namespace: ``str`` *or* ``null``
+    :param page_size: Limit the number of entries returned.
+    :type page_size: ``int``
+    :param page_offset: Offset within list, in units of pageSize chunks.
+    :type page_offset: ``int``
+    :rtype: ``list`` of :py:class:`v1_11_9.web.vo.SnapshotCapacityData`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/capacity/snapshot"
-    query_params = {"container": container}
+    query_params = {"container": container, "namespace": namespace, "pageSize": page_size, "pageOffset": page_offset}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
     if query_dct:
         url_params = urlencode(query_dct)
