@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,38 +17,34 @@
 """
 Package "delphix"
 """
-API_VERSION = "1.5.3"
-
-from delphixpy.v1_5_3 import response_validator
-
-def login(engine, login_request):
-    """
-    Establishes an authenticated user session.
-
-    :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_5_3.delphix_engine.DelphixEngine`
-    :param login_request: Payload object.
-    :type login_request: :py:class:`v1_5_3.web.vo.LoginRequest`
-    :rtype: ``TEXT_TYPE``
-    """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
-    url = "/resources/json/delphix/login"
-    response = engine.post(url, login_request.to_dict(dirty=True) if login_request else None)
-    result = response_validator.validate(response, engine)
-    raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+from delphixpy.v1_11_9 import response_validator
 
 def logout(engine):
     """
     Logs the current authenticated user out.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_5_3.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_11_9.delphix_engine.DelphixEngine`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/logout"
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
     return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
 
+def login(engine, login_request):
+    """
+    Establishes an authenticated user session.
+
+    :param engine: The Delphix Engine
+    :type engine: :py:class:`delphixpy.v1_11_9.delphix_engine.DelphixEngine`
+    :param login_request: Payload object.
+    :type login_request: :py:class:`v1_11_9.web.vo.LoginRequest`
+    :rtype: ``str``
+    """
+    url = "/resources/json/delphix/login"
+    response = engine.post(url, login_request.to_dict(dirty=True) if login_request else None)
+    result = response_validator.validate(response, engine)
+    raw_result = getattr(engine, 'raw_result', False)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
+
