@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,13 +17,8 @@
 """
 Package "jetstream.capacity.branch"
 """
-API_VERSION = "1.4.1"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_4_1 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_4_0 import response_validator
 
 def list_branch_capacity_data(engine, branch=None, data_container=None):
     """
@@ -32,19 +26,18 @@ def list_branch_capacity_data(engine, branch=None, data_container=None):
     capacity breakdown for all Jet Stream branches is returned.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_4_1.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_0.delphix_engine.DelphixEngine`
     :param branch: If passed in, this query parameter restricts the API to only
         return the capacity information for the given branch. This parameter is
         mutually exclusive with the "dataContainer" parameter.
-    :type branch: ``TEXT_TYPE``
+    :type branch: ``str``
     :param data_container: If passed in, this query parameter restricts the API
         to only return the capacity information for all branches in the given
         data container. This parameter is mutually exclusive with the "branch"
         parameter.
-    :type data_container: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_4_1.web.vo.JSBranchCapacityData`
+    :type data_container: ``str``
+    :rtype: ``list`` of :py:class:`v1_4_0.web.vo.JSBranchCapacityData`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/capacity/branch/listBranchCapacityData"
     query_params = {"branch": branch, "dataContainer": data_container}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
