@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,67 +17,59 @@
 """
 Package "policy"
 """
-API_VERSION = "1.11.10"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_10 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_4_0 import response_validator
 
 def create(engine, policy=None):
     """
     Create a new Policy object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_0.delphix_engine.DelphixEngine`
     :param policy: Payload object.
-    :type policy: :py:class:`v1_11_10.web.vo.Policy`
-    :rtype: ``TEXT_TYPE``
+    :type policy: :py:class:`v1_4_0.web.vo.Policy`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/policy"
     response = engine.post(url, policy.to_dict(dirty=True) if policy else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified Policy object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_10.web.objects.Policy.Policy` object
+        :py:class:`delphixpy.v1_4_0.web.objects.Policy.Policy` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_10.web.vo.Policy`
+    :rtype: :py:class:`v1_4_0.web.vo.Policy`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/policy/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
     return response_validator.parse_result(result, undef_enabled=True, return_types=['Policy'], returns_list=False, raw_result=raw_result)
 
-def get_all(engine, type=None, target=None, effective=None):
+def get_all(engine, effective=None, target=None, type=None):
     """
     Returns a list of policies in the domain.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
-    :param type: Limit policies to those of the given type.
-    :type type: ``TEXT_TYPE``
+    :type engine: :py:class:`delphixpy.v1_4_0.delphix_engine.DelphixEngine`
+    :param effective: Whether to include effective policies for the target.
+    :type effective: ``str``
     :param target: Limit policies to those affecting a particular object on the
         system.
-    :type target: ``TEXT_TYPE``
-    :param effective: Whether to include effective policies for the target.
-    :type effective: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_11_10.web.vo.Policy`
+    :type target: ``str``
+    :param type: Limit policies to those of the given type.
+    :type type: ``str``
+    :rtype: ``list`` of :py:class:`v1_4_0.web.vo.Policy`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/policy"
-    query_params = {"type": type, "target": target, "effective": effective}
+    query_params = {"effective": effective, "target": target, "type": type}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
     if query_dct:
         url_params = urlencode(query_dct)
@@ -93,14 +84,13 @@ def update(engine, ref, policy=None):
     Update the specified Policy object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_10.web.objects.Policy.Policy` object
+        :py:class:`delphixpy.v1_4_0.web.objects.Policy.Policy` object
     :type ref: ``str``
     :param policy: Payload object.
-    :type policy: :py:class:`v1_11_10.web.vo.Policy`
+    :type policy: :py:class:`v1_4_0.web.vo.Policy`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/policy/%s" % ref
     response = engine.post(url, policy.to_dict(dirty=True) if policy else None)
     result = response_validator.validate(response, engine)
@@ -112,12 +102,11 @@ def delete(engine, ref):
     Delete the specified Policy object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_10.web.objects.Policy.Policy` object
+        :py:class:`delphixpy.v1_4_0.web.objects.Policy.Policy` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/policy/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -129,15 +118,14 @@ def apply(engine, ref, policy_apply_target_parameters):
     Apply the policy to the specified target.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_10.web.objects.Policy.Policy` object
+        :py:class:`delphixpy.v1_4_0.web.objects.Policy.Policy` object
     :type ref: ``str``
     :param policy_apply_target_parameters: Payload object.
     :type policy_apply_target_parameters:
-        :py:class:`v1_11_10.web.vo.PolicyApplyTargetParameters`
+        :py:class:`v1_4_0.web.vo.PolicyApplyTargetParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/policy/%s/apply" % ref
     response = engine.post(url, policy_apply_target_parameters.to_dict(dirty=True) if policy_apply_target_parameters else None)
     result = response_validator.validate(response, engine)
@@ -149,15 +137,14 @@ def unapply(engine, ref, policy_apply_target_parameters):
     Unapply the policy on the specified target.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_10.web.objects.Policy.Policy` object
+        :py:class:`delphixpy.v1_4_0.web.objects.Policy.Policy` object
     :type ref: ``str``
     :param policy_apply_target_parameters: Payload object.
     :type policy_apply_target_parameters:
-        :py:class:`v1_11_10.web.vo.PolicyApplyTargetParameters`
+        :py:class:`v1_4_0.web.vo.PolicyApplyTargetParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/policy/%s/unapply" % ref
     response = engine.post(url, policy_apply_target_parameters.to_dict(dirty=True) if policy_apply_target_parameters else None)
     result = response_validator.validate(response, engine)
@@ -169,16 +156,15 @@ def create_and_apply(engine, policy_create_and_apply_parameters):
     Create and apply a new policy.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_10.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_0.delphix_engine.DelphixEngine`
     :param policy_create_and_apply_parameters: Payload object.
     :type policy_create_and_apply_parameters:
-        :py:class:`v1_11_10.web.vo.PolicyCreateAndApplyParameters`
-    :rtype: ``TEXT_TYPE``
+        :py:class:`v1_4_0.web.vo.PolicyCreateAndApplyParameters`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/policy/createAndApply"
     response = engine.post(url, policy_create_and_apply_parameters.to_dict(dirty=True) if policy_create_and_apply_parameters else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
