@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,33 +17,23 @@
 """
 Package "capacity.system.historical"
 """
-API_VERSION = "1.11.14"
+from urllib.parse import urlencode
+from delphixpy.v1_4_1 import response_validator
 
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_14 import response_validator
-
-def get_all(engine, start_date=None, end_date=None, resolution=None):
+def get_all(engine, end_date=None, start_date=None):
     """
     Lists historical system capacity data.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_14.delphix_engine.DelphixEngine`
-    :param start_date: Earliest date for which to list data.
-    :type start_date: ``TEXT_TYPE``
+    :type engine: :py:class:`delphixpy.v1_4_1.delphix_engine.DelphixEngine`
     :param end_date: Latest date for which to list data.
-    :type end_date: ``TEXT_TYPE``
-    :param resolution: The time range each datapoint should represent, measured
-        in seconds.
-    :type resolution: ``int``
-    :rtype: ``list`` of
-        :py:class:`v1_11_14.web.vo.HistoricalSystemCapacityData`
+    :type end_date: ``str``
+    :param start_date: Earliest date for which to list data.
+    :type start_date: ``str``
+    :rtype: ``list`` of :py:class:`v1_4_1.web.vo.HistoricalSystemCapacityData`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/capacity/system/historical"
-    query_params = {"startDate": start_date, "endDate": end_date, "resolution": resolution}
+    query_params = {"endDate": end_date, "startDate": start_date}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
     if query_dct:
         url_params = urlencode(query_dct)
