@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,33 +17,27 @@
 """
 Package "jetstream.capacity.bookmark"
 """
-API_VERSION = "1.4.0"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_4_0 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_4_1 import response_validator
 
 def list_bookmark_capacity_data(engine, bookmark=None, data_layout=None):
     """
     Lists the capacity breakdown for Jet Stream bookmarks.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_4_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_1.delphix_engine.DelphixEngine`
     :param bookmark: If passed in, this query parameter restricts the API to
         only return the capacity information for the given bookmark. By
         default, the capacity information for all bookmarks is returned. This
         parameter is mutually exclusive with the "dataLayout" parameter.
-    :type bookmark: ``TEXT_TYPE``
+    :type bookmark: ``str``
     :param data_layout: If passed in, this query parameter restricts the API to
         only return the capacity information for all bookmarks in the given
         data layout. This parameter is mutually exclusive with the "bookmark"
         parameter.
-    :type data_layout: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_4_0.web.vo.JSBookmarkCapacityData`
+    :type data_layout: ``str``
+    :rtype: ``list`` of :py:class:`v1_4_1.web.vo.JSBookmarkCapacityData`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/capacity/bookmark/listBookmarkCapacityData"
     query_params = {"bookmark": bookmark, "dataLayout": data_layout}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
