@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,26 +17,20 @@
 """
 Package "sourceconfig.oracle.pdb"
 """
-API_VERSION = "1.5.0"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_5_0 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_4_1 import response_validator
 
 def get_all(engine, cdb_config=None):
     """
     Returns a list of Oracle PDB configs within a container database.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_1.delphix_engine.DelphixEngine`
     :param cdb_config: Restrict PDB configs to those belonging to the specified
         CDB source config.
-    :type cdb_config: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_5_0.web.vo.OraclePDBConfig`
+    :type cdb_config: ``str``
+    :rtype: ``list`` of :py:class:`v1_4_1.web.vo.OraclePDBConfig`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/sourceconfig/oracle/pdb"
     query_params = {"cdbConfig": cdb_config}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
