@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,40 +17,36 @@
 """
 Package "alert.profile"
 """
-API_VERSION = "1.5.3"
-
-from delphixpy.v1_5_3 import response_validator
+from delphixpy.v1_4_2 import response_validator
 
 def create(engine, alert_profile=None):
     """
     Create a new AlertProfile object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_5_3.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_2.delphix_engine.DelphixEngine`
     :param alert_profile: Payload object.
-    :type alert_profile: :py:class:`v1_5_3.web.vo.AlertProfile`
-    :rtype: ``TEXT_TYPE``
+    :type alert_profile: :py:class:`v1_4_2.web.vo.AlertProfile`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/alert/profile"
     response = engine.post(url, alert_profile.to_dict(dirty=True) if alert_profile else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified AlertProfile object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_5_3.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_2.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_5_3.web.objects.AlertProfile.AlertProfile`
+        :py:class:`delphixpy.v1_4_2.web.objects.AlertProfile.AlertProfile`
         object
     :type ref: ``str``
-    :rtype: :py:class:`v1_5_3.web.vo.AlertProfile`
+    :rtype: :py:class:`v1_4_2.web.vo.AlertProfile`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/alert/profile/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -63,10 +58,9 @@ def get_all(engine):
     List AlertProfile objects on the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_5_3.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of :py:class:`v1_5_3.web.vo.AlertProfile`
+    :type engine: :py:class:`delphixpy.v1_4_2.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_4_2.web.vo.AlertProfile`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/alert/profile"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -78,15 +72,14 @@ def update(engine, ref, alert_profile=None):
     Update the specified AlertProfile object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_5_3.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_2.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_5_3.web.objects.AlertProfile.AlertProfile`
+        :py:class:`delphixpy.v1_4_2.web.objects.AlertProfile.AlertProfile`
         object
     :type ref: ``str``
     :param alert_profile: Payload object.
-    :type alert_profile: :py:class:`v1_5_3.web.vo.AlertProfile`
+    :type alert_profile: :py:class:`v1_4_2.web.vo.AlertProfile`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/alert/profile/%s" % ref
     response = engine.post(url, alert_profile.to_dict(dirty=True) if alert_profile else None)
     result = response_validator.validate(response, engine)
@@ -98,13 +91,12 @@ def delete(engine, ref):
     Delete the specified AlertProfile object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_5_3.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_2.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_5_3.web.objects.AlertProfile.AlertProfile`
+        :py:class:`delphixpy.v1_4_2.web.objects.AlertProfile.AlertProfile`
         object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/alert/profile/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
