@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,44 +17,37 @@
 """
 Package "environment.oracle.clusternode"
 """
-API_VERSION = "1.9.1"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_9_1 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_4_3 import response_validator
 
 def create(engine, oracle_cluster_node_create_parameters):
     """
     Create a new OracleClusterNode object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_1.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
     :param oracle_cluster_node_create_parameters: Payload object.
     :type oracle_cluster_node_create_parameters:
-        :py:class:`v1_9_1.web.vo.OracleClusterNodeCreateParameters`
-    :rtype: ``TEXT_TYPE``
+        :py:class:`v1_4_3.web.vo.OracleClusterNodeCreateParameters`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/oracle/clusternode"
     response = engine.post(url, oracle_cluster_node_create_parameters.to_dict(dirty=True) if oracle_cluster_node_create_parameters else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified OracleClusterNode object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_1.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_9_1.web.objects.OracleCl
+    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_4_3.web.objects.OracleCl
         usterNode.OracleClusterNode` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_9_1.web.vo.OracleClusterNode`
+    :rtype: :py:class:`v1_4_3.web.vo.OracleClusterNode`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/oracle/clusternode/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -67,12 +59,11 @@ def get_all(engine, cluster=None):
     Returns a list of host nodes filtered by cluster.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_1.delphix_engine.DelphixEngine`
-    :param cluster: The cluster to filter by.
-    :type cluster: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_9_1.web.vo.OracleClusterNode`
+    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
+    :param cluster: None
+    :type cluster: ``str``
+    :rtype: ``list`` of :py:class:`v1_4_3.web.vo.OracleClusterNode`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/oracle/clusternode"
     query_params = {"cluster": cluster}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -89,14 +80,13 @@ def update(engine, ref, oracle_cluster_node=None):
     Update the specified OracleClusterNode object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_1.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_9_1.web.objects.OracleCl
+    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_4_3.web.objects.OracleCl
         usterNode.OracleClusterNode` object
     :type ref: ``str``
     :param oracle_cluster_node: Payload object.
-    :type oracle_cluster_node: :py:class:`v1_9_1.web.vo.OracleClusterNode`
+    :type oracle_cluster_node: :py:class:`v1_4_3.web.vo.OracleClusterNode`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/oracle/clusternode/%s" % ref
     response = engine.post(url, oracle_cluster_node.to_dict(dirty=True) if oracle_cluster_node else None)
     result = response_validator.validate(response, engine)
@@ -108,12 +98,11 @@ def delete(engine, ref):
     Delete the specified OracleClusterNode object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_1.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_9_1.web.objects.OracleCl
+    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_4_3.web.objects.OracleCl
         usterNode.OracleClusterNode` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/environment/oracle/clusternode/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
