@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,27 +17,21 @@
 """
 Package "jetstream.capacity.bookmark.tag"
 """
-API_VERSION = "1.4.0"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_4_0 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_4_3 import response_validator
 
 def list_bookmark_tag_capacity_data(engine, bookmark_tag=None):
     """
     Lists the capacity breakdown for Jet Stream bookmark tags.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_4_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
     :param bookmark_tag: If passed in, this query parameter restricts the API
         to only return the capacity information for the given bookmark tag. By
         default, the capacity information for all bookmarks tags is returned.
-    :type bookmark_tag: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_4_0.web.vo.JSBookmarkTagCapacityData`
+    :type bookmark_tag: ``str``
+    :rtype: ``list`` of :py:class:`v1_4_3.web.vo.JSBookmarkTagCapacityData`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/capacity/bookmark/tag/listBookmarkTagCapacityData"
     query_params = {"bookmarkTag": bookmark_tag}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
