@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,32 +17,26 @@
 """
 Package "jetstream.capacity.container"
 """
-API_VERSION = "1.4.2"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_4_2 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_4_3 import response_validator
 
 def list_container_capacity_data(engine, data_container=None, template=None):
     """
     Lists the capacity breakdown for data containers.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_4_2.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
     :param data_container: If passed in, this query parameter restricts the API
         to only return the capacity information for the given data container.
         This parameter is mutually exclusive with the "template" parameter.
-    :type data_container: ``TEXT_TYPE``
+    :type data_container: ``str``
     :param template: If passed in, this query parameter restricts the API to
         only return the capacity information for all of the data containers
         from the given data template. This parameter is mutually exclusive with
         the "dataContainer" parameter.
-    :type template: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_4_2.web.vo.JSContainerCapacityData`
+    :type template: ``str``
+    :rtype: ``list`` of :py:class:`v1_4_3.web.vo.JSContainerCapacityData`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/capacity/container/listContainerCapacityData"
     query_params = {"dataContainer": data_container, "template": template}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
