@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,74 +17,61 @@
 """
 Package "jetstream.container"
 """
-API_VERSION = "1.8.0"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_8_0 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_4_3 import response_validator
 
 def create(engine, js_data_container_create_parameters):
     """
     Create a new JSDataContainer object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
     :param js_data_container_create_parameters: Payload object.
     :type js_data_container_create_parameters:
-        :py:class:`v1_8_0.web.vo.JSDataContainerCreateParameters`
-    :rtype: ``TEXT_TYPE``
+        :py:class:`v1_4_3.web.vo.JSDataContainerCreateParameters`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/container"
     response = engine.post(url, js_data_container_create_parameters.to_dict(dirty=True) if js_data_container_create_parameters else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified JSDataContainer object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_8_0.web.objects.JSDataContainer.JSDataContainer
+        :py:class:`delphixpy.v1_4_3.web.objects.JSDataContainer.JSDataContainer
         ` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_8_0.web.vo.JSDataContainer`
+    :rtype: :py:class:`v1_4_3.web.vo.JSDataContainer`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/container/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
     return response_validator.parse_result(result, undef_enabled=True, return_types=['JSDataContainer'], returns_list=False, raw_result=raw_result)
 
-def get_all(engine, independent_only=None, owner=None, template=None):
+def get_all(engine, owner=None, template=None):
     """
     List the data containers defined in the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_0.delphix_engine.DelphixEngine`
-    :param independent_only: Restrict data containers to independent data
-        containers that do not have templates. This option is mutually
-        exclusive with the "template" and "owner" options.
-    :type independent_only: ``bool``
+    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
     :param owner: Restrict data containers to those belonging to the specified
-        user.This option is mutually exclusive with the "template" and
-        "independentOnly" options.
-    :type owner: ``TEXT_TYPE``
+        user. This option is mutually exclusive with the "template" option.
+    :type owner: ``str``
     :param template: Restrict data containers to those provisioned from the
         specified template. This option is mutually exclusive with the "owner"
-        and "independentOnly" options.
-    :type template: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_8_0.web.vo.JSDataContainer`
+        option.
+    :type template: ``str``
+    :rtype: ``list`` of :py:class:`v1_4_3.web.vo.JSDataContainer`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/container"
-    query_params = {"independentOnly": independent_only, "owner": owner, "template": template}
+    query_params = {"owner": owner, "template": template}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
     if query_dct:
         url_params = urlencode(query_dct)
@@ -100,60 +86,33 @@ def update(engine, ref, js_data_container=None):
     Update the specified JSDataContainer object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_8_0.web.objects.JSDataContainer.JSDataContainer
+        :py:class:`delphixpy.v1_4_3.web.objects.JSDataContainer.JSDataContainer
         ` object
     :type ref: ``str``
     :param js_data_container: Payload object.
-    :type js_data_container: :py:class:`v1_8_0.web.vo.JSDataContainer`
+    :type js_data_container: :py:class:`v1_4_3.web.vo.JSDataContainer`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/container/%s" % ref
     response = engine.post(url, js_data_container.to_dict(dirty=True) if js_data_container else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
     return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
 
-def delete(engine, ref, js_data_container_delete_parameters=None):
+def delete(engine, ref):
     """
-    Delete this data container.
+    Delete the specified JSDataContainer object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_8_0.web.objects.JSDataContainer.JSDataContainer
+        :py:class:`delphixpy.v1_4_3.web.objects.JSDataContainer.JSDataContainer
         ` object
     :type ref: ``str``
-    :param js_data_container_delete_parameters: Payload object.
-    :type js_data_container_delete_parameters:
-        :py:class:`v1_8_0.web.vo.JSDataContainerDeleteParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/container/%s/delete" % ref
-    response = engine.post(url, js_data_container_delete_parameters.to_dict(dirty=True) if js_data_container_delete_parameters else None)
-    result = response_validator.validate(response, engine)
-    raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
-
-def add_owner(engine, ref, js_data_container_modify_owner_parameters):
-    """
-    Grant authorizations for the given user on this container and parent
-    template.
-
-    :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_0.delphix_engine.DelphixEngine`
-    :param ref: Reference to a
-        :py:class:`delphixpy.v1_8_0.web.objects.JSDataContainer.JSDataContainer
-        ` object
-    :type ref: ``str``
-    :param js_data_container_modify_owner_parameters: Payload object.
-    :type js_data_container_modify_owner_parameters:
-        :py:class:`v1_8_0.web.vo.JSDataContainerModifyOwnerParameters`
-    """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
-    url = "/resources/json/delphix/jetstream/container/%s/addOwner" % ref
-    response = engine.post(url, js_data_container_modify_owner_parameters.to_dict(dirty=True) if js_data_container_modify_owner_parameters else None)
+    response = engine.post(url, None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
     return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
@@ -163,13 +122,12 @@ def disable(engine, ref):
     Disable this data container.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_8_0.web.objects.JSDataContainer.JSDataContainer
+        :py:class:`delphixpy.v1_4_3.web.objects.JSDataContainer.JSDataContainer
         ` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/container/%s/disable" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -181,13 +139,12 @@ def enable(engine, ref):
     Enable this data container.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_8_0.web.objects.JSDataContainer.JSDataContainer
+        :py:class:`delphixpy.v1_4_3.web.objects.JSDataContainer.JSDataContainer
         ` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/container/%s/enable" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -199,35 +156,33 @@ def get_active_branch_at_time(engine, ref, js_data_container_active_branch_param
     Return the branch that was active for the given time.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_8_0.web.objects.JSDataContainer.JSDataContainer
+        :py:class:`delphixpy.v1_4_3.web.objects.JSDataContainer.JSDataContainer
         ` object
     :type ref: ``str``
     :param js_data_container_active_branch_parameters: Payload object.
     :type js_data_container_active_branch_parameters:
-        :py:class:`v1_8_0.web.vo.JSDataContainerActiveBranchParameters`
-    :rtype: ``TEXT_TYPE``
+        :py:class:`v1_4_3.web.vo.JSDataContainerActiveBranchParameters`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/container/%s/getActiveBranchAtTime" % ref
     response = engine.post(url, js_data_container_active_branch_parameters.to_dict(dirty=True) if js_data_container_active_branch_parameters else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def recover(engine, ref):
     """
     Recover this data container from the INCONSISTENT state.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_8_0.web.objects.JSDataContainer.JSDataContainer
+        :py:class:`delphixpy.v1_4_3.web.objects.JSDataContainer.JSDataContainer
         ` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/container/%s/recover" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -239,53 +194,29 @@ def refresh(engine, ref):
     Refresh this data container to the latest data from its template.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_8_0.web.objects.JSDataContainer.JSDataContainer
+        :py:class:`delphixpy.v1_4_3.web.objects.JSDataContainer.JSDataContainer
         ` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/container/%s/refresh" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
     return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
 
-def remove_owner(engine, ref, js_data_container_modify_owner_parameters):
-    """
-    Revoke authorizations for the given user on this container and parent
-    template.
-
-    :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_0.delphix_engine.DelphixEngine`
-    :param ref: Reference to a
-        :py:class:`delphixpy.v1_8_0.web.objects.JSDataContainer.JSDataContainer
-        ` object
-    :type ref: ``str``
-    :param js_data_container_modify_owner_parameters: Payload object.
-    :type js_data_container_modify_owner_parameters:
-        :py:class:`v1_8_0.web.vo.JSDataContainerModifyOwnerParameters`
-    """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
-    url = "/resources/json/delphix/jetstream/container/%s/removeOwner" % ref
-    response = engine.post(url, js_data_container_modify_owner_parameters.to_dict(dirty=True) if js_data_container_modify_owner_parameters else None)
-    result = response_validator.validate(response, engine)
-    raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
-
 def reset(engine, ref):
     """
     Reset the data container to the last data operation.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_8_0.web.objects.JSDataContainer.JSDataContainer
+        :py:class:`delphixpy.v1_4_3.web.objects.JSDataContainer.JSDataContainer
         ` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/container/%s/reset" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -298,59 +229,35 @@ def restore(engine, ref, js_timeline_point_parameters):
     timeline point parameters.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_8_0.web.objects.JSDataContainer.JSDataContainer
+        :py:class:`delphixpy.v1_4_3.web.objects.JSDataContainer.JSDataContainer
         ` object
     :type ref: ``str``
     :param js_timeline_point_parameters: Payload object.
     :type js_timeline_point_parameters:
-        :py:class:`v1_8_0.web.vo.JSTimelinePointParameters`
+        :py:class:`v1_4_3.web.vo.JSTimelinePointParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/container/%s/restore" % ref
     response = engine.post(url, js_timeline_point_parameters.to_dict(dirty=True) if js_timeline_point_parameters else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
     return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
 
-def undo(engine, ref, js_data_container_undo_parameters):
-    """
-    Undo the given operation. This is only valid for RESET, RESTORE, UNDO, and
-    REFRESH operations.
-
-    :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_0.delphix_engine.DelphixEngine`
-    :param ref: Reference to a
-        :py:class:`delphixpy.v1_8_0.web.objects.JSDataContainer.JSDataContainer
-        ` object
-    :type ref: ``str``
-    :param js_data_container_undo_parameters: Payload object.
-    :type js_data_container_undo_parameters:
-        :py:class:`v1_8_0.web.vo.JSDataContainerUndoParameters`
-    """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
-    url = "/resources/json/delphix/jetstream/container/%s/undo" % ref
-    response = engine.post(url, js_data_container_undo_parameters.to_dict(dirty=True) if js_data_container_undo_parameters else None)
-    result = response_validator.validate(response, engine)
-    raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
-
 def list_by_top_operation_count(engine, max_result_size=None, template=None):
     """
     Return child data containers for a given template sorted by operationCount.
     Can optionally limit to the top maxResultSize data containers.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
     :param max_result_size: The maximum number of results to return. A value of
         0 means all are returned.
     :type max_result_size: ``int``
     :param template: The given data template.
-    :type template: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_8_0.web.vo.JSDataContainer`
+    :type template: ``str``
+    :rtype: ``list`` of :py:class:`v1_4_3.web.vo.JSDataContainer`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/container/listByTopOperationCount"
     query_params = {"maxResultSize": max_result_size, "template": template}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
