@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,30 +17,24 @@
 """
 Package "notification"
 """
-API_VERSION = "1.7.0"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_7_0 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_4_3 import response_validator
 
 def get_all(engine, channel=None, max=None, timeout=None):
     """
     Returns a list of pending notifications for the current session.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_7_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
     :param channel: Client-specific ID to specify an independent channel.
-    :type channel: ``TEXT_TYPE``
-    :param max: Maximum number of entries to return at once.
-    :type max: ``TEXT_TYPE``
+    :type channel: ``str``
+    :param max: Maximum number of entries to reutrn at once.
+    :type max: ``str``
     :param timeout: Timeout, in milliseconds, to wait for one or more
         responses.
-    :type timeout: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_7_0.web.vo.Notification`
+    :type timeout: ``str``
+    :rtype: ``list`` of :py:class:`v1_4_3.web.vo.Notification`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/notification"
     query_params = {"channel": channel, "max": max, "timeout": timeout}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
