@@ -1,5 +1,5 @@
 # 
-# Copyright 2014, 2022 by Delphix
+# Copyright 2014, 2023 by Delphix
 # 
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -17,13 +17,13 @@
 import json
 import time
 from contextlib import contextmanager
-from delphixpy.v1_11_14 import common
-from delphixpy.v1_11_14 import exceptions
-from delphixpy.v1_11_14 import http_client
-from delphixpy.v1_11_14.job_context import JobMode
-from delphixpy.v1_11_14.web import delphix as auth
-from delphixpy.v1_11_14.web import session
-from delphixpy.v1_11_14.web.vo import APISession, APIVersion, LoginRequest
+from delphixpy.v1_5_0 import common
+from delphixpy.v1_5_0 import exceptions
+from delphixpy.v1_5_0 import http_client
+from delphixpy.v1_5_0.job_context import JobMode
+from delphixpy.v1_5_0.web import delphix as auth
+from delphixpy.v1_5_0.web import session
+from delphixpy.v1_5_0.web.vo import APISession, APIVersion, LoginRequest
 
 REFRESH_LOGIN_TIMEOUT = 25  # Time before refreshing our login in minutes
 
@@ -42,20 +42,20 @@ def create_session(engine):
     api_session.locale = API_LOCALE
     api_version = APIVersion()
     api_version.major = 1
-    api_version.minor = 11
-    api_version.micro = 14
+    api_version.minor = 5
+    api_version.micro = 0
     api_session.version = api_version
 
     return session.set(engine, api_session)
 
 
-class HttpMethod(object):
+class HttpMethod:
     """HTTP method enumeration"""
     POST = 'POST'
     GET = 'GET'
 
 
-class HttpSession(object):
+class HttpSession:
     """
     This class keeps a HTTP session
     """
@@ -67,7 +67,7 @@ class HttpSession(object):
         :type host: str
         :param client: The class of the client used for perfoming HTTP requests
         """
-        super(HttpSession, self).__init__()
+        super().__init__()
         self._host = host
         self._cookie = None
         self._client = client(host)
@@ -139,7 +139,7 @@ class HttpSession(object):
         return self._handle_response(response, HttpMethod.GET, path)
 
 
-class LoginHelper(object):
+class LoginHelper:
     """
     This class helps with logging in to the Delphix engine
     """
@@ -160,14 +160,14 @@ class LoginHelper(object):
                           engine
         :type namespace: str
         """
-        super(LoginHelper, self).__init__()
+        super().__init__()
         self._username = username
         self._password = password
         self._namespace = namespace
         self._http_session = http_session
         self._time_at_last_login = None
 
-    API_VERSION = "1.11.14"
+    API_VERSION = "1.5.0"
 
     def force_relogin(self):
         self._time_at_last_login = None
@@ -219,7 +219,7 @@ class LoginHelper(object):
         self._time_at_last_login = time.time()
 
 
-class DelphixEngine(object):
+class DelphixEngine:
     """
     This class represents the Delphix appliance
     """
@@ -242,7 +242,7 @@ class DelphixEngine(object):
         self._job_contexts = []
         self._last_job = None
 
-    API_VERSION = "1.11.14"
+    API_VERSION = "1.5.0"
 
     def __repr__(self):
         return ("DelphixEngine(address='%s', delphix_session=%s)"
@@ -270,7 +270,7 @@ class DelphixEngine(object):
     def _create_session(self):
         outer = self
 
-        class EngineProxy(object):
+        class EngineProxy:
             API_VERSION = outer.API_VERSION
 
             def post(self, url, data_to_post):
