@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,39 +17,36 @@
 """
 Package "database.template"
 """
-API_VERSION = "1.11.16"
-
-from delphixpy.v1_11_16 import response_validator
+from delphixpy.v1_5_0 import response_validator
 
 def create(engine, database_template=None):
     """
     Create a new DatabaseTemplate object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_16.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
     :param database_template: Payload object.
-    :type database_template: :py:class:`v1_11_16.web.vo.DatabaseTemplate`
-    :rtype: ``TEXT_TYPE``
+    :type database_template: :py:class:`v1_5_0.web.vo.DatabaseTemplate`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/database/template"
     response = engine.post(url, database_template.to_dict(dirty=True) if database_template else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified DatabaseTemplate object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_16.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_16.web.objects.Databa
-        seTemplate.DatabaseTemplate` object
+    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
+    :param ref: Reference to a
+        :py:class:`delphixpy.v1_5_0.web.objects.DatabaseTemplate.DatabaseTempla
+        te` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_16.web.vo.DatabaseTemplate`
+    :rtype: :py:class:`v1_5_0.web.vo.DatabaseTemplate`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/database/template/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -62,10 +58,9 @@ def get_all(engine):
     List DatabaseTemplate objects on the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_16.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of :py:class:`v1_11_16.web.vo.DatabaseTemplate`
+    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_5_0.web.vo.DatabaseTemplate`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/database/template"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -77,14 +72,14 @@ def update(engine, ref, database_template=None):
     Update the specified DatabaseTemplate object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_16.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_16.web.objects.Databa
-        seTemplate.DatabaseTemplate` object
+    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
+    :param ref: Reference to a
+        :py:class:`delphixpy.v1_5_0.web.objects.DatabaseTemplate.DatabaseTempla
+        te` object
     :type ref: ``str``
     :param database_template: Payload object.
-    :type database_template: :py:class:`v1_11_16.web.vo.DatabaseTemplate`
+    :type database_template: :py:class:`v1_5_0.web.vo.DatabaseTemplate`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/database/template/%s" % ref
     response = engine.post(url, database_template.to_dict(dirty=True) if database_template else None)
     result = response_validator.validate(response, engine)
@@ -96,12 +91,12 @@ def delete(engine, ref):
     Delete the specified DatabaseTemplate object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_16.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_16.web.objects.Databa
-        seTemplate.DatabaseTemplate` object
+    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
+    :param ref: Reference to a
+        :py:class:`delphixpy.v1_5_0.web.objects.DatabaseTemplate.DatabaseTempla
+        te` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/database/template/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -113,10 +108,9 @@ def config(engine):
     Return a list of static template configuration information.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_16.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of :py:class:`v1_11_16.web.vo.DatabaseTemplateConfig`
+    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_5_0.web.vo.DatabaseTemplateConfig`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/database/template/config"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
