@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,50 +17,43 @@
 """
 Package "jetstream.datasource"
 """
-API_VERSION = "1.9.1"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_9_1 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_5_0 import response_validator
 
 def get(engine, ref):
     """
     Retrieve the specified JSDataSource object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_1.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_9_1.web.objects.JSDataSource.JSDataSource`
+        :py:class:`delphixpy.v1_5_0.web.objects.JSDataSource.JSDataSource`
         object
     :type ref: ``str``
-    :rtype: :py:class:`v1_9_1.web.vo.JSDataSource`
+    :rtype: :py:class:`v1_5_0.web.vo.JSDataSource`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/datasource/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
     return response_validator.parse_result(result, undef_enabled=True, return_types=['JSDataSource'], returns_list=False, raw_result=raw_result)
 
-def get_all(engine, data_layout=None, container=None):
+def get_all(engine, container=None, data_layout=None):
     """
     Lists the Jet Stream data sources in the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_1.delphix_engine.DelphixEngine`
-    :param data_layout: List the sources associated with the given data layout
-        reference.
-    :type data_layout: ``TEXT_TYPE``
+    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
     :param container: List the source associated with the given container
         reference.
-    :type container: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_9_1.web.vo.JSDataSource`
+    :type container: ``str``
+    :param data_layout: List the sources associated with the given data layout
+        reference.
+    :type data_layout: ``str``
+    :rtype: ``list`` of :py:class:`v1_5_0.web.vo.JSDataSource`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/datasource"
-    query_params = {"dataLayout": data_layout, "container": container}
+    query_params = {"container": container, "dataLayout": data_layout}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
     if query_dct:
         url_params = urlencode(query_dct)
@@ -76,15 +68,14 @@ def update(engine, ref, js_data_source=None):
     Update the specified JSDataSource object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_1.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_9_1.web.objects.JSDataSource.JSDataSource`
+        :py:class:`delphixpy.v1_5_0.web.objects.JSDataSource.JSDataSource`
         object
     :type ref: ``str``
     :param js_data_source: Payload object.
-    :type js_data_source: :py:class:`v1_9_1.web.vo.JSDataSource`
+    :type js_data_source: :py:class:`v1_5_0.web.vo.JSDataSource`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/datasource/%s" % ref
     response = engine.post(url, js_data_source.to_dict(dirty=True) if js_data_source else None)
     result = response_validator.validate(response, engine)
@@ -98,13 +89,12 @@ def data_timestamps(engine, js_source_data_timestamp_parameters):
     layout.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_1.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
     :param js_source_data_timestamp_parameters: Payload object.
     :type js_source_data_timestamp_parameters:
-        :py:class:`v1_9_1.web.vo.JSSourceDataTimestampParameters`
-    :rtype: ``list`` of :py:class:`v1_9_1.web.vo.JSSourceDataTimestamp`
+        :py:class:`v1_5_0.web.vo.JSSourceDataTimestampParameters`
+    :rtype: ``list`` of :py:class:`v1_5_0.web.vo.JSSourceDataTimestamp`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/datasource/dataTimestamps"
     response = engine.post(url, js_source_data_timestamp_parameters.to_dict(dirty=True) if js_source_data_timestamp_parameters else None)
     result = response_validator.validate(response, engine)
