@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,13 +17,8 @@
 """
 Package "jetstream.usage.branch"
 """
-API_VERSION = "1.8.1"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_8_1 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_5_0 import response_validator
 
 def list_branch_usage_data(engine, data_container=None):
     """
@@ -32,13 +26,12 @@ def list_branch_usage_data(engine, data_container=None):
     container.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_1.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
     :param data_container: The usage information for the branches on this data
         container will be returned.
-    :type data_container: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_8_1.web.vo.JSBranchUsageData`
+    :type data_container: ``str``
+    :rtype: ``list`` of :py:class:`v1_5_0.web.vo.JSBranchUsageData`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/usage/branch/listBranchUsageData"
     query_params = {"dataContainer": data_container}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
