@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,27 +17,21 @@
 """
 Package "jetstream.usage.user"
 """
-API_VERSION = "1.5.3"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_5_3 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_5_0 import response_validator
 
 def list_user_usage_data(engine, user=None):
     """
     Lists the usage breakdown for Jet Stream users.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_5_3.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
     :param user: If passed in, this query parameter restricts the API to only
         return the usage information for the given user. By default, the usage
         information for all users is returned.
-    :type user: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_5_3.web.vo.JSUserUsageData`
+    :type user: ``str``
+    :rtype: ``list`` of :py:class:`v1_5_0.web.vo.JSUserUsageData`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/usage/user/listUserUsageData"
     query_params = {"user": user}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
