@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,62 +17,46 @@
 """
 Package "source"
 """
-API_VERSION = "1.10.6"
-
-from delphixpy.v1_10_6.web.source import operationTemplate
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_10_6 import response_validator
+from delphixpy.v1_5_0.web.source import operationTemplate
+from urllib.parse import urlencode
+from delphixpy.v1_5_0 import response_validator
 
 def get(engine, ref):
     """
     Retrieve the specified Source object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_10_6.web.objects.Source.Source` object
+        :py:class:`delphixpy.v1_5_0.web.objects.Source.Source` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_10_6.web.vo.Source`
+    :rtype: :py:class:`v1_5_0.web.vo.Source`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/source/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
     return response_validator.parse_result(result, undef_enabled=True, return_types=['Source'], returns_list=False, raw_result=raw_result)
 
-def get_all(engine, database=None, config=None, all_sources=None, repository=None, environment=None, include_hosts=None):
+def get_all(engine, database=None, environment=None, repository=None):
     """
     Lists sources on the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
-    :param database: List visible sources associated with the given container
-        reference. Visible sources are of type LINKED or VIRTUAL.
-    :type database: ``TEXT_TYPE``
-    :param config: List visible sources associated with the given sourceconfig
-        reference. Visible sources are of type LINKED or VIRTUAL.
-    :type config: ``TEXT_TYPE``
-    :param all_sources: List all sources associated with the given source
-        container reference.
-    :type all_sources: ``bool``
-    :param repository: List sources associated with the given source repository
+    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
+    :param database: List sources associated with the given container
         reference.
-    :type repository: ``TEXT_TYPE``
+    :type database: ``str``
     :param environment: List sources associated with the given source
         environment reference.
-    :type environment: ``TEXT_TYPE``
-    :param include_hosts: Whether to include the list of hosts for each source
-        in the response.
-    :type include_hosts: ``bool``
-    :rtype: ``list`` of :py:class:`v1_10_6.web.vo.Source`
+    :type environment: ``str``
+    :param repository: List sources associated with the given source repository
+        reference.
+    :type repository: ``str``
+    :rtype: ``list`` of :py:class:`v1_5_0.web.vo.Source`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/source"
-    query_params = {"database": database, "config": config, "allSources": all_sources, "repository": repository, "environment": environment, "includeHosts": include_hosts}
+    query_params = {"database": database, "environment": environment, "repository": repository}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
     if query_dct:
         url_params = urlencode(query_dct)
@@ -88,74 +71,89 @@ def update(engine, ref, source=None):
     Update the specified Source object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_10_6.web.objects.Source.Source` object
+        :py:class:`delphixpy.v1_5_0.web.objects.Source.Source` object
     :type ref: ``str``
     :param source: Payload object.
-    :type source: :py:class:`v1_10_6.web.vo.Source`
+    :type source: :py:class:`v1_5_0.web.vo.Source`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/source/%s" % ref
     response = engine.post(url, source.to_dict(dirty=True) if source else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
     return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
 
-def enable(engine, ref, source_enable_parameters=None):
-    """
-    Enables the given source.
-
-    :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
-    :param ref: Reference to a
-        :py:class:`delphixpy.v1_10_6.web.objects.Source.Source` object
-    :type ref: ``str``
-    :param source_enable_parameters: Payload object.
-    :type source_enable_parameters:
-        :py:class:`v1_10_6.web.vo.SourceEnableParameters`
-    """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
-    url = "/resources/json/delphix/source/%s/enable" % ref
-    response = engine.post(url, source_enable_parameters.to_dict(dirty=True) if source_enable_parameters else None)
-    result = response_validator.validate(response, engine)
-    raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
-
 def disable(engine, ref, source_disable_parameters=None):
     """
     Disables the given source.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_10_6.web.objects.Source.Source` object
+        :py:class:`delphixpy.v1_5_0.web.objects.Source.Source` object
     :type ref: ``str``
     :param source_disable_parameters: Payload object.
     :type source_disable_parameters:
-        :py:class:`v1_10_6.web.vo.SourceDisableParameters`
+        :py:class:`v1_5_0.web.vo.SourceDisableParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/source/%s/disable" % ref
     response = engine.post(url, source_disable_parameters.to_dict(dirty=True) if source_disable_parameters else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
     return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
 
+def enable(engine, ref, source_enable_parameters=None):
+    """
+    Enables the given source.
+
+    :param engine: The Delphix Engine
+    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
+    :param ref: Reference to a
+        :py:class:`delphixpy.v1_5_0.web.objects.Source.Source` object
+    :type ref: ``str``
+    :param source_enable_parameters: Payload object.
+    :type source_enable_parameters:
+        :py:class:`v1_5_0.web.vo.SourceEnableParameters`
+    """
+    url = "/resources/json/delphix/source/%s/enable" % ref
+    response = engine.post(url, source_enable_parameters.to_dict(dirty=True) if source_enable_parameters else None)
+    result = response_validator.validate(response, engine)
+    raw_result = getattr(engine, 'raw_result', False)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
+
+def populate(engine, ref, fraction_plug_parameters):
+    """
+    Add a TimeFlow to a warehouse source.
+
+    :param engine: The Delphix Engine
+    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
+    :param ref: Reference to a
+        :py:class:`delphixpy.v1_5_0.web.objects.Source.Source` object
+    :type ref: ``str``
+    :param fraction_plug_parameters: Payload object.
+    :type fraction_plug_parameters:
+        :py:class:`v1_5_0.web.vo.FractionPlugParameters`
+    """
+    url = "/resources/json/delphix/source/%s/populate" % ref
+    response = engine.post(url, fraction_plug_parameters.to_dict(dirty=True) if fraction_plug_parameters else None)
+    result = response_validator.validate(response, engine)
+    raw_result = getattr(engine, 'raw_result', False)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
+
 def start(engine, ref, source_start_parameters=None):
     """
     Starts the given source.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_10_6.web.objects.Source.Source` object
+        :py:class:`delphixpy.v1_5_0.web.objects.Source.Source` object
     :type ref: ``str``
     :param source_start_parameters: Payload object.
     :type source_start_parameters:
-        :py:class:`v1_10_6.web.vo.SourceStartParameters`
+        :py:class:`v1_5_0.web.vo.SourceStartParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/source/%s/start" % ref
     response = engine.post(url, source_start_parameters.to_dict(dirty=True) if source_start_parameters else None)
     result = response_validator.validate(response, engine)
@@ -167,15 +165,14 @@ def stop(engine, ref, source_stop_parameters=None):
     Stops the given source.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_10_6.web.objects.Source.Source` object
+        :py:class:`delphixpy.v1_5_0.web.objects.Source.Source` object
     :type ref: ``str``
     :param source_stop_parameters: Payload object.
     :type source_stop_parameters:
-        :py:class:`v1_10_6.web.vo.SourceStopParameters`
+        :py:class:`v1_5_0.web.vo.SourceStopParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/source/%s/stop" % ref
     response = engine.post(url, source_stop_parameters.to_dict(dirty=True) if source_stop_parameters else None)
     result = response_validator.validate(response, engine)
@@ -187,38 +184,17 @@ def upgrade(engine, ref, source_upgrade_parameters=None):
     Upgrades the given source.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_5_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_10_6.web.objects.Source.Source` object
+        :py:class:`delphixpy.v1_5_0.web.objects.Source.Source` object
     :type ref: ``str``
     :param source_upgrade_parameters: Payload object.
     :type source_upgrade_parameters:
-        :py:class:`v1_10_6.web.vo.SourceUpgradeParameters`
+        :py:class:`v1_5_0.web.vo.SourceUpgradeParameters`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/source/%s/upgrade" % ref
     response = engine.post(url, source_upgrade_parameters.to_dict(dirty=True) if source_upgrade_parameters else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
     return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
 
-def populate(engine, ref, fraction_plug_parameters):
-    """
-    Add a TimeFlow to a warehouse source.
-
-    :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_10_6.delphix_engine.DelphixEngine`
-    :param ref: Reference to a
-        :py:class:`delphixpy.v1_10_6.web.objects.Source.Source` object
-    :type ref: ``str``
-    :param fraction_plug_parameters: Payload object.
-    :type fraction_plug_parameters:
-        :py:class:`v1_10_6.web.vo.FractionPlugParameters`
-    """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
-    url = "/resources/json/delphix/source/%s/populate" % ref
-    response = engine.post(url, fraction_plug_parameters.to_dict(dirty=True) if fraction_plug_parameters else None)
-    result = response_validator.validate(response, engine)
-    raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=None, returns_list=None, raw_result=raw_result)
-
