@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,41 +17,37 @@
 """
 Package "jetstream.template"
 """
-API_VERSION = "1.7.0"
-
-from delphixpy.v1_7_0 import response_validator
+from delphixpy.v1_5_1 import response_validator
 
 def create(engine, js_data_template_create_parameters):
     """
     Create a new JSDataTemplate object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_7_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_5_1.delphix_engine.DelphixEngine`
     :param js_data_template_create_parameters: Payload object.
     :type js_data_template_create_parameters:
-        :py:class:`v1_7_0.web.vo.JSDataTemplateCreateParameters`
-    :rtype: ``TEXT_TYPE``
+        :py:class:`v1_5_1.web.vo.JSDataTemplateCreateParameters`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/template"
     response = engine.post(url, js_data_template_create_parameters.to_dict(dirty=True) if js_data_template_create_parameters else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified JSDataTemplate object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_7_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_5_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_7_0.web.objects.JSDataTemplate.JSDataTemplate`
+        :py:class:`delphixpy.v1_5_1.web.objects.JSDataTemplate.JSDataTemplate`
         object
     :type ref: ``str``
-    :rtype: :py:class:`v1_7_0.web.vo.JSDataTemplate`
+    :rtype: :py:class:`v1_5_1.web.vo.JSDataTemplate`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/template/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -64,10 +59,9 @@ def get_all(engine):
     List the data templates defined in the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_7_0.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of :py:class:`v1_7_0.web.vo.JSDataTemplate`
+    :type engine: :py:class:`delphixpy.v1_5_1.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_5_1.web.vo.JSDataTemplate`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/template"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -79,15 +73,14 @@ def update(engine, ref, js_data_template=None):
     Update the specified JSDataTemplate object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_7_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_5_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_7_0.web.objects.JSDataTemplate.JSDataTemplate`
+        :py:class:`delphixpy.v1_5_1.web.objects.JSDataTemplate.JSDataTemplate`
         object
     :type ref: ``str``
     :param js_data_template: Payload object.
-    :type js_data_template: :py:class:`v1_7_0.web.vo.JSDataTemplate`
+    :type js_data_template: :py:class:`v1_5_1.web.vo.JSDataTemplate`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/template/%s" % ref
     response = engine.post(url, js_data_template.to_dict(dirty=True) if js_data_template else None)
     result = response_validator.validate(response, engine)
@@ -99,13 +92,12 @@ def delete(engine, ref):
     Delete the specified JSDataTemplate object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_7_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_5_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_7_0.web.objects.JSDataTemplate.JSDataTemplate`
+        :py:class:`delphixpy.v1_5_1.web.objects.JSDataTemplate.JSDataTemplate`
         object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/template/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
