@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,26 +17,20 @@
 """
 Package "analytics.statistic"
 """
-API_VERSION = "1.11.8"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_8 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_5_2 import response_validator
 
 def get(engine, ref):
     """
     Retrieve the specified Statistic object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_8.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_5_2.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_8.web.objects.Statistic.Statistic` object
+        :py:class:`delphixpy.v1_5_2.web.objects.Statistic.Statistic` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_8.web.vo.Statistic`
+    :rtype: :py:class:`v1_5_2.web.vo.Statistic`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/analytics/statistic/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -49,10 +42,9 @@ def get_all(engine):
     Returns a list of statistics in the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_8.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of :py:class:`v1_11_8.web.vo.Statistic`
+    :type engine: :py:class:`delphixpy.v1_5_2.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_5_2.web.vo.Statistic`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/analytics/statistic"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -64,12 +56,11 @@ def show_axes(engine, statistic_type=None):
     Returns the set of axes for a statistic type.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_8.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_5_2.delphix_engine.DelphixEngine`
     :param statistic_type: None
-    :type statistic_type: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_11_8.web.vo.StatisticAxis`
+    :type statistic_type: ``str``
+    :rtype: ``list`` of :py:class:`v1_5_2.web.vo.StatisticAxis`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/analytics/statistic/showAxes"
     query_params = {"statisticType": statistic_type}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
