@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,56 +17,48 @@
 """
 Package "fault.effect"
 """
-API_VERSION = "1.11.0"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_0 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_6_0 import response_validator
 
 def get(engine, ref):
     """
     Retrieve the specified FaultEffect object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_6_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_0.web.objects.FaultEffect.FaultEffect`
-        object
+        :py:class:`delphixpy.v1_6_0.web.objects.FaultEffect.FaultEffect` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_0.web.vo.FaultEffect`
+    :rtype: :py:class:`v1_6_0.web.vo.FaultEffect`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/fault/effect/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
     return response_validator.parse_result(result, undef_enabled=True, return_types=['FaultEffect'], returns_list=False, raw_result=raw_result)
 
-def get_all(engine, severity=None, target=None, root_cause=None, bundle_id=None):
+def get_all(engine, bundle_id=None, root_cause=None, severity=None, target=None):
     """
     Returns the list of all the fault effects that match the given criteria.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_0.delphix_engine.DelphixEngine`
-    :param severity: The impact of the fault effect on the system: CRITICAL or
-        WARNING. *(permitted values: CRITICAL, WARNING)*
-    :type severity: ``TEXT_TYPE``
-    :param target: The reference to the Delphix user-visible object associated
-        with the fault effect.
-    :type target: ``TEXT_TYPE``
-    :param root_cause: The reference to the fault which is the root cause of
-        the fault effect.
-    :type root_cause: ``TEXT_TYPE``
+    :type engine: :py:class:`delphixpy.v1_6_0.delphix_engine.DelphixEngine`
     :param bundle_id: A unique dot delimited identifier associated with the
         fault effect.
-    :type bundle_id: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_11_0.web.vo.FaultEffect`
+    :type bundle_id: ``str``
+    :param root_cause: The reference to the fault which is the root cause of
+        the fault effect.
+    :type root_cause: ``str``
+    :param severity: The impact of the fault effect on the system: CRITICAL or
+        WARNING. *(permitted values: CRITICAL, WARNING)*
+    :type severity: ``str``
+    :param target: The reference to the Delphix user-visible object associated
+        with the fault effect.
+    :type target: ``str``
+    :rtype: ``list`` of :py:class:`v1_6_0.web.vo.FaultEffect`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/fault/effect"
-    query_params = {"severity": severity, "target": target, "rootCause": root_cause, "bundleID": bundle_id}
+    query_params = {"bundleID": bundle_id, "rootCause": root_cause, "severity": severity, "target": target}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
     if query_dct:
         url_params = urlencode(query_dct)
