@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,40 +17,36 @@
 """
 Package "replication.spec"
 """
-API_VERSION = "1.6.2"
-
-from delphixpy.v1_6_2 import response_validator
+from delphixpy.v1_6_0 import response_validator
 
 def create(engine, replication_spec=None):
     """
     Create a new ReplicationSpec object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_6_2.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_6_0.delphix_engine.DelphixEngine`
     :param replication_spec: Payload object.
-    :type replication_spec: :py:class:`v1_6_2.web.vo.ReplicationSpec`
-    :rtype: ``TEXT_TYPE``
+    :type replication_spec: :py:class:`v1_6_0.web.vo.ReplicationSpec`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/replication/spec"
     response = engine.post(url, replication_spec.to_dict(dirty=True) if replication_spec else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified ReplicationSpec object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_6_2.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_6_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_6_2.web.objects.ReplicationSpec.ReplicationSpec
+        :py:class:`delphixpy.v1_6_0.web.objects.ReplicationSpec.ReplicationSpec
         ` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_6_2.web.vo.ReplicationSpec`
+    :rtype: :py:class:`v1_6_0.web.vo.ReplicationSpec`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/replication/spec/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -63,10 +58,9 @@ def get_all(engine):
     List ReplicationSpec objects on the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_6_2.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of :py:class:`v1_6_2.web.vo.ReplicationSpec`
+    :type engine: :py:class:`delphixpy.v1_6_0.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_6_0.web.vo.ReplicationSpec`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/replication/spec"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -78,15 +72,14 @@ def update(engine, ref, replication_spec=None):
     Update the specified ReplicationSpec object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_6_2.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_6_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_6_2.web.objects.ReplicationSpec.ReplicationSpec
+        :py:class:`delphixpy.v1_6_0.web.objects.ReplicationSpec.ReplicationSpec
         ` object
     :type ref: ``str``
     :param replication_spec: Payload object.
-    :type replication_spec: :py:class:`v1_6_2.web.vo.ReplicationSpec`
+    :type replication_spec: :py:class:`v1_6_0.web.vo.ReplicationSpec`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/replication/spec/%s" % ref
     response = engine.post(url, replication_spec.to_dict(dirty=True) if replication_spec else None)
     result = response_validator.validate(response, engine)
@@ -98,13 +91,12 @@ def delete(engine, ref):
     Delete the specified ReplicationSpec object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_6_2.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_6_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_6_2.web.objects.ReplicationSpec.ReplicationSpec
+        :py:class:`delphixpy.v1_6_0.web.objects.ReplicationSpec.ReplicationSpec
         ` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/replication/spec/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -116,13 +108,12 @@ def execute(engine, ref):
     Manually trigger execution of a replication spec.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_6_2.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_6_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_6_2.web.objects.ReplicationSpec.ReplicationSpec
+        :py:class:`delphixpy.v1_6_0.web.objects.ReplicationSpec.ReplicationSpec
         ` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/replication/spec/%s/execute" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
