@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,44 +17,37 @@
 """
 Package "jetstream.branch"
 """
-API_VERSION = "1.9.0"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_9_0 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_6_1 import response_validator
 
 def create(engine, js_branch_create_parameters):
     """
     Create a new JSBranch object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_6_1.delphix_engine.DelphixEngine`
     :param js_branch_create_parameters: Payload object.
     :type js_branch_create_parameters:
-        :py:class:`v1_9_0.web.vo.JSBranchCreateParameters`
-    :rtype: ``TEXT_TYPE``
+        :py:class:`v1_6_1.web.vo.JSBranchCreateParameters`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/branch"
     response = engine.post(url, js_branch_create_parameters.to_dict(dirty=True) if js_branch_create_parameters else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified JSBranch object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_6_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_9_0.web.objects.JSBranch.JSBranch` object
+        :py:class:`delphixpy.v1_6_1.web.objects.JSBranch.JSBranch` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_9_0.web.vo.JSBranch`
+    :rtype: :py:class:`v1_6_1.web.vo.JSBranch`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/branch/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -67,12 +59,11 @@ def get_all(engine, data_layout=None):
     Lists the Jet Stream branches in the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_6_1.delphix_engine.DelphixEngine`
     :param data_layout: List branches belonging to the given data layout.
-    :type data_layout: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_9_0.web.vo.JSBranch`
+    :type data_layout: ``str``
+    :rtype: ``list`` of :py:class:`v1_6_1.web.vo.JSBranch`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/branch"
     query_params = {"dataLayout": data_layout}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -89,14 +80,13 @@ def update(engine, ref, js_branch=None):
     Update the specified JSBranch object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_6_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_9_0.web.objects.JSBranch.JSBranch` object
+        :py:class:`delphixpy.v1_6_1.web.objects.JSBranch.JSBranch` object
     :type ref: ``str``
     :param js_branch: Payload object.
-    :type js_branch: :py:class:`v1_9_0.web.vo.JSBranch`
+    :type js_branch: :py:class:`v1_6_1.web.vo.JSBranch`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/branch/%s" % ref
     response = engine.post(url, js_branch.to_dict(dirty=True) if js_branch else None)
     result = response_validator.validate(response, engine)
@@ -108,12 +98,11 @@ def delete(engine, ref):
     Delete the specified JSBranch object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_6_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_9_0.web.objects.JSBranch.JSBranch` object
+        :py:class:`delphixpy.v1_6_1.web.objects.JSBranch.JSBranch` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/branch/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
@@ -125,12 +114,11 @@ def activate(engine, ref):
     Makes this branch the current branch for its data layout.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_9_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_6_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_9_0.web.objects.JSBranch.JSBranch` object
+        :py:class:`delphixpy.v1_6_1.web.objects.JSBranch.JSBranch` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/branch/%s/activate" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
