@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,45 +17,38 @@
 """
 Package "timeflow.bookmark"
 """
-API_VERSION = "1.11.7"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_7 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_6_1 import response_validator
 
 def create(engine, timeflow_bookmark_create_parameters):
     """
     Create a new TimeflowBookmark object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_6_1.delphix_engine.DelphixEngine`
     :param timeflow_bookmark_create_parameters: Payload object.
     :type timeflow_bookmark_create_parameters:
-        :py:class:`v1_11_7.web.vo.TimeflowBookmarkCreateParameters`
-    :rtype: ``TEXT_TYPE``
+        :py:class:`v1_6_1.web.vo.TimeflowBookmarkCreateParameters`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/timeflow/bookmark"
     response = engine.post(url, timeflow_bookmark_create_parameters.to_dict(dirty=True) if timeflow_bookmark_create_parameters else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified TimeflowBookmark object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_6_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_7.web.objects.TimeflowBookmark.TimeflowBookm
-        ark` object
+        :py:class:`delphixpy.v1_6_1.web.objects.TimeflowBookmark.TimeflowBookma
+        rk` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_7.web.vo.TimeflowBookmark`
+    :rtype: :py:class:`v1_6_1.web.vo.TimeflowBookmark`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/timeflow/bookmark/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -68,12 +60,11 @@ def get_all(engine, database=None):
     Returns a list of all TimeFlow bookmarks.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_6_1.delphix_engine.DelphixEngine`
     :param database: Filter results based on specified database.
-    :type database: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_11_7.web.vo.TimeflowBookmark`
+    :type database: ``str``
+    :rtype: ``list`` of :py:class:`v1_6_1.web.vo.TimeflowBookmark`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/timeflow/bookmark"
     query_params = {"database": database}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -90,13 +81,12 @@ def delete(engine, ref):
     Delete the specified TimeflowBookmark object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_7.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_6_1.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_11_7.web.objects.TimeflowBookmark.TimeflowBookm
-        ark` object
+        :py:class:`delphixpy.v1_6_1.web.objects.TimeflowBookmark.TimeflowBookma
+        rk` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/timeflow/bookmark/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
