@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,41 +17,36 @@
 """
 Package "host.privilegeElevation.profileScript"
 """
-API_VERSION = "1.10.5"
-
-from delphixpy.v1_10_5 import response_validator
+from delphixpy.v1_7_0 import response_validator
 
 def create(engine, host_privilege_elevation_profile_script=None):
     """
     Create a new HostPrivilegeElevationProfileScript object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_10_5.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_7_0.delphix_engine.DelphixEngine`
     :param host_privilege_elevation_profile_script: Payload object.
     :type host_privilege_elevation_profile_script:
-        :py:class:`v1_10_5.web.vo.HostPrivilegeElevationProfileScript`
-    :rtype: ``TEXT_TYPE``
+        :py:class:`v1_7_0.web.vo.HostPrivilegeElevationProfileScript`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/host/privilegeElevation/profileScript"
     response = engine.post(url, host_privilege_elevation_profile_script.to_dict(dirty=True) if host_privilege_elevation_profile_script else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified HostPrivilegeElevationProfileScript object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_10_5.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_10_5.web.objects.HostPri
-        vilegeElevationProfileScript.HostPrivilegeElevationProfileScript`
-        object
+    :type engine: :py:class:`delphixpy.v1_7_0.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_7_0.web.objects.HostPriv
+        ilegeElevationProfileScript.HostPrivilegeElevationProfileScript` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_10_5.web.vo.HostPrivilegeElevationProfileScript`
+    :rtype: :py:class:`v1_7_0.web.vo.HostPrivilegeElevationProfileScript`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/host/privilegeElevation/profileScript/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -64,11 +58,10 @@ def get_all(engine):
     List HostPrivilegeElevationProfileScript objects on the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_10_5.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_7_0.delphix_engine.DelphixEngine`
     :rtype: ``list`` of
-        :py:class:`v1_10_5.web.vo.HostPrivilegeElevationProfileScript`
+        :py:class:`v1_7_0.web.vo.HostPrivilegeElevationProfileScript`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/host/privilegeElevation/profileScript"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -80,16 +73,14 @@ def update(engine, ref, host_privilege_elevation_profile_script=None):
     Update the specified HostPrivilegeElevationProfileScript object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_10_5.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_10_5.web.objects.HostPri
-        vilegeElevationProfileScript.HostPrivilegeElevationProfileScript`
-        object
+    :type engine: :py:class:`delphixpy.v1_7_0.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_7_0.web.objects.HostPriv
+        ilegeElevationProfileScript.HostPrivilegeElevationProfileScript` object
     :type ref: ``str``
     :param host_privilege_elevation_profile_script: Payload object.
     :type host_privilege_elevation_profile_script:
-        :py:class:`v1_10_5.web.vo.HostPrivilegeElevationProfileScript`
+        :py:class:`v1_7_0.web.vo.HostPrivilegeElevationProfileScript`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/host/privilegeElevation/profileScript/%s" % ref
     response = engine.post(url, host_privilege_elevation_profile_script.to_dict(dirty=True) if host_privilege_elevation_profile_script else None)
     result = response_validator.validate(response, engine)
@@ -101,13 +92,11 @@ def delete(engine, ref):
     Delete the specified HostPrivilegeElevationProfileScript object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_10_5.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_10_5.web.objects.HostPri
-        vilegeElevationProfileScript.HostPrivilegeElevationProfileScript`
-        object
+    :type engine: :py:class:`delphixpy.v1_7_0.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_7_0.web.objects.HostPriv
+        ilegeElevationProfileScript.HostPrivilegeElevationProfileScript` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/host/privilegeElevation/profileScript/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
