@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,26 +17,20 @@
 """
 Package "toolkit"
 """
-API_VERSION = "1.5.1"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_5_1 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_7_0 import response_validator
 
 def get(engine, ref):
     """
     Retrieve the specified Toolkit object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_5_1.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_7_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_5_1.web.objects.Toolkit.Toolkit` object
+        :py:class:`delphixpy.v1_7_0.web.objects.Toolkit.Toolkit` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_5_1.web.vo.Toolkit`
+    :rtype: :py:class:`v1_7_0.web.vo.Toolkit`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/toolkit/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -49,13 +42,12 @@ def get_all(engine, source_environment=None):
     Lists installed toolkits.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_5_1.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_7_0.delphix_engine.DelphixEngine`
     :param source_environment: Restricts list to include only toolkits that are
         valid for the given source environment.
-    :type source_environment: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_5_1.web.vo.Toolkit`
+    :type source_environment: ``str``
+    :rtype: ``list`` of :py:class:`v1_7_0.web.vo.Toolkit`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/toolkit"
     query_params = {"sourceEnvironment": source_environment}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -72,12 +64,11 @@ def delete(engine, ref):
     Delete the specified Toolkit object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_5_1.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_7_0.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_5_1.web.objects.Toolkit.Toolkit` object
+        :py:class:`delphixpy.v1_7_0.web.objects.Toolkit.Toolkit` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/toolkit/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
