@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,40 +17,36 @@
 """
 Package "host.privilegeElevation.profile"
 """
-API_VERSION = "1.11.9"
-
-from delphixpy.v1_11_9 import response_validator
+from delphixpy.v1_7_1 import response_validator
 
 def create(engine, host_privilege_elevation_profile=None):
     """
     Create a new HostPrivilegeElevationProfile object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_9.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_7_1.delphix_engine.DelphixEngine`
     :param host_privilege_elevation_profile: Payload object.
     :type host_privilege_elevation_profile:
-        :py:class:`v1_11_9.web.vo.HostPrivilegeElevationProfile`
-    :rtype: ``TEXT_TYPE``
+        :py:class:`v1_7_1.web.vo.HostPrivilegeElevationProfile`
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/host/privilegeElevation/profile"
     response = engine.post(url, host_privilege_elevation_profile.to_dict(dirty=True) if host_privilege_elevation_profile else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
     Retrieve the specified HostPrivilegeElevationProfile object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_9.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_9.web.objects.HostPri
-        vilegeElevationProfile.HostPrivilegeElevationProfile` object
+    :type engine: :py:class:`delphixpy.v1_7_1.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_7_1.web.objects.HostPriv
+        ilegeElevationProfile.HostPrivilegeElevationProfile` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_11_9.web.vo.HostPrivilegeElevationProfile`
+    :rtype: :py:class:`v1_7_1.web.vo.HostPrivilegeElevationProfile`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/host/privilegeElevation/profile/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -63,11 +58,9 @@ def get_all(engine):
     List HostPrivilegeElevationProfile objects on the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_9.delphix_engine.DelphixEngine`
-    :rtype: ``list`` of
-        :py:class:`v1_11_9.web.vo.HostPrivilegeElevationProfile`
+    :type engine: :py:class:`delphixpy.v1_7_1.delphix_engine.DelphixEngine`
+    :rtype: ``list`` of :py:class:`v1_7_1.web.vo.HostPrivilegeElevationProfile`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/host/privilegeElevation/profile"
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -79,15 +72,14 @@ def update(engine, ref, host_privilege_elevation_profile=None):
     Update the specified HostPrivilegeElevationProfile object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_9.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_9.web.objects.HostPri
-        vilegeElevationProfile.HostPrivilegeElevationProfile` object
+    :type engine: :py:class:`delphixpy.v1_7_1.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_7_1.web.objects.HostPriv
+        ilegeElevationProfile.HostPrivilegeElevationProfile` object
     :type ref: ``str``
     :param host_privilege_elevation_profile: Payload object.
     :type host_privilege_elevation_profile:
-        :py:class:`v1_11_9.web.vo.HostPrivilegeElevationProfile`
+        :py:class:`v1_7_1.web.vo.HostPrivilegeElevationProfile`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/host/privilegeElevation/profile/%s" % ref
     response = engine.post(url, host_privilege_elevation_profile.to_dict(dirty=True) if host_privilege_elevation_profile else None)
     result = response_validator.validate(response, engine)
@@ -99,12 +91,11 @@ def delete(engine, ref):
     Delete the specified HostPrivilegeElevationProfile object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_9.delphix_engine.DelphixEngine`
-    :param ref: Reference to a :py:class:`delphixpy.v1_11_9.web.objects.HostPri
-        vilegeElevationProfile.HostPrivilegeElevationProfile` object
+    :type engine: :py:class:`delphixpy.v1_7_1.delphix_engine.DelphixEngine`
+    :param ref: Reference to a :py:class:`delphixpy.v1_7_1.web.objects.HostPriv
+        ilegeElevationProfile.HostPrivilegeElevationProfile` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/host/privilegeElevation/profile/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
