@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,9 +17,6 @@
 """
 Package "network"
 """
-API_VERSION = "1.10.3"
-
-from delphixpy.v1_10_3.web.network import dsp
-from delphixpy.v1_10_3.web.network import interface
-from delphixpy.v1_10_3.web.network import route
-from delphixpy.v1_10_3.web.network import test
+from delphixpy.v1_8_0.web.network import interface
+from delphixpy.v1_8_0.web.network import test
+from delphixpy.v1_8_0.web.network import route
