@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,12 +17,7 @@
 """
 Package "service.tls.cacert"
 """
-API_VERSION = "1.9.0"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
+from urllib.parse import urlencode
 from delphixpy.v1_9_0 import response_validator
 
 def create(engine, certificate_import_parameters):
@@ -35,14 +29,13 @@ def create(engine, certificate_import_parameters):
     :param certificate_import_parameters: Payload object.
     :type certificate_import_parameters:
         :py:class:`v1_9_0.web.vo.CertificateImportParameters`
-    :rtype: ``TEXT_TYPE``
+    :rtype: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/tls/cacert"
     response = engine.post(url, certificate_import_parameters.to_dict(dirty=True) if certificate_import_parameters else None)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
-    return response_validator.parse_result(result, undef_enabled=True, return_types=['TEXT_TYPE'], returns_list=False, raw_result=raw_result)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['str'], returns_list=False, raw_result=raw_result)
 
 def get(engine, ref):
     """
@@ -55,7 +48,6 @@ def get(engine, ref):
     :type ref: ``str``
     :rtype: :py:class:`v1_9_0.web.vo.TlsCaCert`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/tls/cacert/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
@@ -69,10 +61,9 @@ def get_all(engine, alias=None):
     :param engine: The Delphix Engine
     :type engine: :py:class:`delphixpy.v1_9_0.delphix_engine.DelphixEngine`
     :param alias: List the CA with the given alias.
-    :type alias: ``TEXT_TYPE``
+    :type alias: ``str``
     :rtype: ``list`` of :py:class:`v1_9_0.web.vo.TlsCaCert`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/tls/cacert"
     query_params = {"alias": alias}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -94,7 +85,6 @@ def delete(engine, ref):
         :py:class:`delphixpy.v1_9_0.web.objects.TlsCaCert.TlsCaCert` object
     :type ref: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/service/tls/cacert/%s/delete" % ref
     response = engine.post(url, None)
     result = response_validator.validate(response, engine)
