@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,34 +17,28 @@
 """
 Package "capacity.consumer.historical"
 """
-API_VERSION = "1.11.8"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_8 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_9_2 import response_validator
 
 def get_all(engine, container=None, start_date=None, end_date=None, resolution=None):
     """
     Lists consumers in the system.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_8.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_9_2.delphix_engine.DelphixEngine`
     :param container: The container for which to list data.
-    :type container: ``TEXT_TYPE``
+    :type container: ``str``
     :param start_date: Earliest date for which to list data.
-    :type start_date: ``TEXT_TYPE``
+    :type start_date: ``str``
     :param end_date: Latest date for which to list data.
-    :type end_date: ``TEXT_TYPE``
+    :type end_date: ``str``
     :param resolution: The time range each datapoint should represent, measured
         in seconds. This parameter is only meaningful if a container is
         specified.
     :type resolution: ``int``
     :rtype: ``list`` of
-        :py:class:`v1_11_8.web.vo.HistoricalConsumerCapacityData`
+        :py:class:`v1_9_2.web.vo.HistoricalConsumerCapacityData`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/capacity/consumer/historical"
     query_params = {"container": container, "startDate": start_date, "endDate": end_date, "resolution": resolution}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
