@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,25 +17,19 @@
 """
 Package "data"
 """
-API_VERSION = "1.8.0"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_8_0 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_9_3 import response_validator
 
 def download(engine, token=None):
     """
     Download the resource.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_8_0.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_9_3.delphix_engine.DelphixEngine`
     :param token: A token that uniquely identifies a resource stored on the
         Delphix Engine.
-    :type token: ``TEXT_TYPE``
+    :type token: ``str``
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/data/download"
     query_params = {"token": token}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
