@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,13 +17,8 @@
 """
 Package "database.performanceHistory"
 """
-API_VERSION = "1.11.15"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_11_15 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_9_3 import response_validator
 
 def get_all(engine, from_date=None, to_date=None, sampling_interval=None):
     """
@@ -32,19 +26,18 @@ def get_all(engine, from_date=None, to_date=None, sampling_interval=None):
     time.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_11_15.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_9_3.delphix_engine.DelphixEngine`
     :param from_date: The earliest date for which container utilization
         statistics will be reported.
-    :type from_date: ``TEXT_TYPE``
+    :type from_date: ``str``
     :param to_date: The latest date for which container utilization statistics
         will be reported.
-    :type to_date: ``TEXT_TYPE``
+    :type to_date: ``str``
     :param sampling_interval: The interval at which data is to be sampled,
         measured in seconds.
     :type sampling_interval: ``float``
-    :rtype: ``list`` of :py:class:`v1_11_15.web.vo.ContainerUtilization`
+    :rtype: ``list`` of :py:class:`v1_9_3.web.vo.ContainerUtilization`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/database/performanceHistory"
     query_params = {"fromDate": from_date, "toDate": to_date, "samplingInterval": sampling_interval}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
