@@ -1,6 +1,5 @@
-# coding: utf8
 #
-# Copyright 2022 by Delphix
+# Copyright 2023 by Delphix
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,69 +17,62 @@
 """
 Package "jetstream.operation"
 """
-API_VERSION = "1.4.3"
-
-try:
-    from urllib import urlencode 
-except ImportError:
-    from urllib.parse import urlencode 
-from delphixpy.v1_4_3 import response_validator
+from urllib.parse import urlencode
+from delphixpy.v1_9_3 import response_validator
 
 def get(engine, ref):
     """
     Retrieve the specified JSOperation object.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_9_3.delphix_engine.DelphixEngine`
     :param ref: Reference to a
-        :py:class:`delphixpy.v1_4_3.web.objects.JSOperation.JSOperation` object
+        :py:class:`delphixpy.v1_9_3.web.objects.JSOperation.JSOperation` object
     :type ref: ``str``
-    :rtype: :py:class:`v1_4_3.web.vo.JSOperation`
+    :rtype: :py:class:`v1_9_3.web.vo.JSOperation`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/operation/%s" % ref
     response = engine.get(url)
     result = response_validator.validate(response, engine)
     raw_result = getattr(engine, 'raw_result', False)
     return response_validator.parse_result(result, undef_enabled=True, return_types=['JSOperation'], returns_list=False, raw_result=raw_result)
 
-def get_all(engine, after_count=None, before_count=None, branch=None, data_end_time=None, data_layout=None, data_start_time=None, data_time=None):
+def get_all(engine, data_layout=None, branch=None, data_time=None, before_count=None, after_count=None, data_start_time=None, data_end_time=None):
     """
     Lists the Jet Stream action history for a data layout.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
-    :param after_count: The suggested maximum number of visible operations
-        after "dataTime" that should be returned. If there are not sufficient
-        events after additional events before may be returned.
-    :type after_count: ``int``
+    :type engine: :py:class:`delphixpy.v1_9_3.delphix_engine.DelphixEngine`
+    :param data_layout: Limit operations to the specific data layout. This
+        option is mutually exclusive with the "branch" option.
+    :type data_layout: ``str``
+    :param branch: Limit operations to the specified branch. This option is
+        mutually exclusive with the "dataLayout" option.
+    :type branch: ``str``
+    :param data_time: Limit operations that occurred around the specified
+        "dataTime". "beforeCount" and "afterCount" should specify the number of
+        events to be returned.
+    :type data_time: ``str``
     :param before_count: The suggested maximum number of visible operations
         prior to "dataTime" that should be returned. If there are not
         sufficient events before additional events after may be returned.
     :type before_count: ``int``
-    :param branch: Limit operations to the specified branch. This option is
-        mutually exclusive with the "dataLayout" option.
-    :type branch: ``TEXT_TYPE``
-    :param data_end_time: Operations with "dataTime" before this value will be
-        returned. Used with "dataStartTime" to return a set of operations
-        between two dates.
-    :type data_end_time: ``TEXT_TYPE``
-    :param data_layout: Limit operations to the specific data layout. This
-        option is mutually exclusive with the "branch" option.
-    :type data_layout: ``TEXT_TYPE``
+    :param after_count: The suggested maximum number of visible operations
+        after "dataTime" that should be returned. If there are not sufficient
+        events after additional events before may be returned.
+    :type after_count: ``int``
     :param data_start_time: Operations with "dataTime" after this value will be
         returned. Used with "dataEndTime" to return a set of operations between
         two dates.
-    :type data_start_time: ``TEXT_TYPE``
-    :param data_time: Limit operations that occured around the specified
-        "dataTime". "beforeCount" and "afterCount" should specify the number of
-        events to be returned.
-    :type data_time: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_4_3.web.vo.JSOperation`
+    :type data_start_time: ``str``
+    :param data_end_time: Operations with "dataTime" before this value will be
+        returned. Used with "dataStartTime" to return a set of operations
+        between two dates.
+    :type data_end_time: ``str``
+    :rtype: ``list`` of :py:class:`v1_9_3.web.vo.JSOperation`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/operation"
-    query_params = {"afterCount": after_count, "beforeCount": before_count, "branch": branch, "dataEndTime": data_end_time, "dataLayout": data_layout, "dataStartTime": data_start_time, "dataTime": data_time}
+    query_params = {"dataLayout": data_layout, "branch": branch, "dataTime": data_time, "beforeCount": before_count, "afterCount": after_count, "dataStartTime": data_start_time, "dataEndTime": data_end_time}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
     if query_dct:
         url_params = urlencode(query_dct)
@@ -95,13 +87,12 @@ def endpoint(engine, js_operation_endpoint_parameters):
     Return the first and last operation for the specified parameters.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_9_3.delphix_engine.DelphixEngine`
     :param js_operation_endpoint_parameters: Payload object.
     :type js_operation_endpoint_parameters:
-        :py:class:`v1_4_3.web.vo.JSOperationEndpointParameters`
-    :rtype: :py:class:`v1_4_3.web.vo.JSOperationEndpoint`
+        :py:class:`v1_9_3.web.vo.JSOperationEndpointParameters`
+    :rtype: :py:class:`v1_9_3.web.vo.JSOperationEndpoint`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/operation/endpoint"
     response = engine.post(url, js_operation_endpoint_parameters.to_dict(dirty=True) if js_operation_endpoint_parameters else None)
     result = response_validator.validate(response, engine)
@@ -114,12 +105,11 @@ def list_operations_by_action(engine, action=None):
     action.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_9_3.delphix_engine.DelphixEngine`
     :param action: The given action.
-    :type action: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_4_3.web.vo.JSOperation`
+    :type action: ``str``
+    :rtype: ``list`` of :py:class:`v1_9_3.web.vo.JSOperation`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/operation/listOperationsByAction"
     query_params = {"action": action}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -136,12 +126,11 @@ def list_operations_by_job(engine, job=None):
     Return the list of operations spawned by the root action of the given job.
 
     :param engine: The Delphix Engine
-    :type engine: :py:class:`delphixpy.v1_4_3.delphix_engine.DelphixEngine`
+    :type engine: :py:class:`delphixpy.v1_9_3.delphix_engine.DelphixEngine`
     :param job: The given job.
-    :type job: ``TEXT_TYPE``
-    :rtype: ``list`` of :py:class:`v1_4_3.web.vo.JSOperation`
+    :type job: ``str``
+    :rtype: ``list`` of :py:class:`v1_9_3.web.vo.JSOperation`
     """
-    assert API_VERSION == engine.API_VERSION, "Wrong API version (%s) for parameter 'engine' (%s)" % (API_VERSION, engine.API_VERSION)
     url = "/resources/json/delphix/jetstream/operation/listOperationsByJob"
     query_params = {"job": job}
     query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
@@ -153,3 +142,25 @@ def list_operations_by_job(engine, job=None):
     raw_result = getattr(engine, 'raw_result', False)
     return response_validator.parse_result(result, undef_enabled=True, return_types=['JSOperation'], returns_list=True, raw_result=raw_result)
 
+def list_operations_by_template(engine, template=None):
+    """
+    Return the list of operations in the system for a given Jet Stream data
+    template.
+
+    :param engine: The Delphix Engine
+    :type engine: :py:class:`delphixpy.v1_9_3.delphix_engine.DelphixEngine`
+    :param template: The given template.
+    :type template: ``str``
+    :rtype: ``list`` of :py:class:`v1_9_3.web.vo.JSOperation`
+    """
+    url = "/resources/json/delphix/jetstream/operation/listOperationsByTemplate"
+    query_params = {"template": template}
+    query_dct = {k: query_params[k] for k in query_params if query_params[k] is not None}
+    if query_dct:
+        url_params = urlencode(query_dct)
+        url += "?%s" % url_params
+    response = engine.get(url)
+    result = response_validator.validate(response, engine)
+    raw_result = getattr(engine, 'raw_result', False)
+    return response_validator.parse_result(result, undef_enabled=True, return_types=['JSOperation'], returns_list=True, raw_result=raw_result)
+
